@@ -91,8 +91,8 @@ wxThread::ExitCode CAddFileThread::Entry()
     		wxPostEvent(theApp.xmuledlg,evt);
 	}
 
-	free(hashfile->name);
-	free(hashfile->directory);
+	delete[] hashfile->name;
+	delete[] hashfile->directory;
   	delete hashfile;
     }
 }
