@@ -577,7 +577,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 	data->Write(&tagcount,4);
 	CTag tag(ET_COMPRESSION,1);
 	tag.WriteTagToFile(data);
-	CTag tag2(ET_UDPVER,2);
+	CTag tag2(ET_UDPVER, 3); /* From aMule 1.1.1 */
 	tag2.WriteTagToFile(data);
 	CTag tag3(ET_UDPPORT,theApp.glob_prefs->GetUDPPort());
 	tag3.WriteTagToFile(data);
@@ -585,9 +585,9 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 	tag4.WriteTagToFile(data);
 	CTag tag5(ET_COMMENTS,1);
 	tag5.WriteTagToFile(data);
-	CTag tag6(ET_EXTENDEDREQUEST,1);
+	CTag tag6(ET_EXTENDEDREQUEST, 2); /* From aMule 1.1.1 */
 	tag6.WriteTagToFile(data);
-	CTag tag7(ET_COMPATABLECLIENT,2);
+	CTag tag7(ET_COMPATABLECLIENT, 2);
 	tag7.WriteTagToFile(data);
 	// Maella end
 	Packet* packet = new Packet(data,OP_EMULEPROT);
