@@ -91,10 +91,9 @@ CClientCreditsList::~CClientCreditsList()
 {
 	SaveList();
 	CClientCredits* cur_credit;
-	CCKey tmpkey(0);
 	POSITION pos = m_mapClients.GetStartPosition();
 	while (pos){
-		m_mapClients.GetNextAssoc(pos, tmpkey, cur_credit);
+		m_mapClients.GetNextAssoc(pos, cur_credit);
 		delete cur_credit;
 	}
 	m_mapClients.RemoveAll();
@@ -217,12 +216,11 @@ void CClientCreditsList::SaveList()
 	}
 
 	CClientCredits* cur_credit;
-	CCKey tempkey(0);
 	POSITION pos = m_mapClients.GetStartPosition();
 	count = 0;
 	while (pos)
 	{
-		m_mapClients.GetNextAssoc(pos, tempkey, cur_credit);
+		m_mapClients.GetNextAssoc(pos, cur_credit);
 		if (cur_credit->GetDataStruct()->nUploaded + cur_credit->GetDataStruct()->nDownloaded > 0)
 		{
 			memcpy(pBuffer+(count*sizeof(CreditStruct)), cur_credit->GetDataStruct(), sizeof(CreditStruct));
@@ -294,10 +292,9 @@ CClientCreditsList::CClientCreditsList(CPreferences* in_prefs){
 CClientCreditsList::~CClientCreditsList(){
 	SaveList();
 	CClientCredits* cur_credit;
-	CCKey tmpkey(0);
 	POSITION pos = client_map.GetStartPosition();
 	while (pos){
-		client_map.GetNextAssoc(pos,tmpkey,cur_credit);
+		client_map.GetNextAssoc(pos,cur_credit);
 		delete cur_credit;
 	}
 	client_map.RemoveAll();
@@ -360,11 +357,10 @@ void CClientCreditsList::SaveList(){
 	uint32 count = client_map.GetCount();
 	file.Write(&count,4);
 	CClientCredits* cur_credit;
-	CCKey tempkey(0);
 	POSITION pos = client_map.GetStartPosition();
 	count = 0;
 	while (pos){
-		client_map.GetNextAssoc(pos,tempkey,cur_credit);
+		client_map.GetNextAssoc(pos,cur_credit);
 		if (cur_credit->GetDataStruct()->uploaded + cur_credit->GetDataStruct()->downloaded > 0){ 
           file.Write(cur_credit->GetDataStruct(),sizeof(Credit_Struct)); 
           count++; 
