@@ -84,18 +84,28 @@ bool CClientUDPSocket::ProcessPacket(char* packet, int16 size, int8 opcode, char
 					break;
 				}
 				CUpDownClient* sender = theApp.uploadqueue->GetWaitingClientByIP(inet_addr(host));
-				if (sender){
+				if (sender) {
+					sender->AddAskedCount();
 					sender->SetUDPPort(port);
 					sender->UDPFileReasked();
-					break;
-				}
-				else{
-					if (((uint32)theApp.uploadqueue->GetWaitingUserCount() + 50) > theApp.glob_prefs->GetQueueSize()){
+/*					if ((sender->GetUDPVersion() > 2) && (size > 17)) {
+						uint16 nCompleteCountLast= sender->GetUpCompleteSourcesCount();
+						uint16 nCompleteCountNew= *(uint16*)(packet+16);
+						sender->SetUpCompleteSourcesCount(nCompleteCountNew);
+						if (nCompleteCountLast != nCompleteCountNew) {
+							if(reqfile->IsPartFile()) {
+								((CPartFile*)reqfile)->NewSrcPartsInfo();
+							} else {
+								reqfile->NewAvailPartsInfo();
+							}
+						}
+					}*/
+				} else {
+					if (((uint32)theApp.uploadqueue->GetWaitingUserCount() + 50) > theApp.glob_prefs->GetQueueSize()) {
 						Packet* response = new Packet(OP_QUEUEFULL,0,OP_EMULEPROT);
 						theApp.uploadqueue->AddUpDataOverheadFileRequest(response->size);
 						SendPacket(response,inet_addr(host),port);
 					}
-					break;
 				}
 				break;
 			}
