@@ -30,6 +30,7 @@ struct UDPPack{
 	Packet* packet;
 	uint32 dwIP;
 	uint16 nPort;
+	int    trial;
 };
 #pragma pack()
 
@@ -53,7 +54,7 @@ protected:
 	virtual void	OnReceive(int nErrorCode);
 private:
 	void	ClearQueues();	
-	int		SendTo(char* lpBuf,int nBufLen,uint32 dwIP, uint16 nPort);
+	bool		SendTo(char* lpBuf,int nBufLen,uint32 dwIP, uint16 nPort);
 	bool	m_bWouldBlock;
 
 	CTypedPtrList<CPtrList, UDPPack*> controlpacket_queue;
