@@ -26,7 +26,7 @@ static char THIS_FILE[]=__FILE__;
 #define HTREEITEM wxCTreeItemId
 
 IMPLEMENT_DYNAMIC_CLASS(CDirectoryTreeCtrl, wxCTreeCtrl)
-CDirectoryTreeCtrl::CDirectoryTreeCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags)
+CDirectoryTreeCtrl::CDirectoryTreeCtrl(wxWindow* parent,int id,const wxPoint& pos,wxSize siz,int flags)
   : wxCTreeCtrl(parent,id,pos,siz,flags,wxDefaultValidator,"ShareTree"),
     m_image(16,16)
 {
