@@ -143,12 +143,13 @@ bool CUpDownClient::IsSourceRequestAllowed() {
 }
 
 void CUpDownClient::SendFileRequest(){
-	if(!reqfile)
+	if(!reqfile) {
 		return;
+	}
 	AddAskedCountDown();
 	CMemFile* data = new CMemFile();
 	data->Write(reqfile->GetFileHash(),16);
-	if( GetExtendedRequestsVersion() > 0 ){
+	if( GetExtendedRequestsVersion() > 0 ) {
 		reqfile->WritePartStatus(data);
 	}
 	Packet* packet = new Packet(data);
@@ -156,15 +157,18 @@ void CUpDownClient::SendFileRequest(){
 	theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
 	socket->SendPacket(packet, true);
 	delete data;
-	data = new CMemFile();
-	data->Write(reqfile->GetFileHash(),16);
-	packet = new Packet(data);
-	packet->opcode = OP_SETREQFILEID;
-	theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
-	socket->SendPacket(packet, true);
-	delete data;
-	if( IsEmuleClient() )
+	if (reqfile->GetPartCount() > 1) {
+		data = new CMemFile();
+		data->Write(reqfile->GetFileHash(),16);
+		packet = new Packet(data);
+		packet->opcode = OP_SETREQFILEID;
+		theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
+		socket->SendPacket(packet, true);
+		delete data;
+	}
+	if ( IsEmuleClient() ) {
 		SetRemoteQueueFull( true );
+	}
 	SetRemoteQueueRank(0);
 	
 	if(IsSourceRequestAllowed()) {
