@@ -389,15 +389,20 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* sou
 		return;
 
 	// use this for client which are already know (downloading for example)
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+	for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
-		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
-		if (cur_file->srclists[sl].Find(source)){
-			if (cur_file == sender)
-				return;
-			if (source->AddRequestForAnotherFile(sender))
-				theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,true);
-			return;
+		for (int sl=0;sl<SOURCESSLOTS;sl++) {
+			if (!cur_file->srclists[sl].IsEmpty()) {
+				if (cur_file->srclists[sl].Find(source)) {
+					if (cur_file == sender) {
+						return;
+					}
+					if (source->AddRequestForAnotherFile(sender)) {
+						theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,true);
+					}	
+					return;
+				}
+			}
 		}
 	}
 	source->SetDownloadFile(sender);
