@@ -1,6 +1,6 @@
 /*
   This file is part of xMule
-  Copyright (C) 2002 Madcat ( madcat@xmule.org / http://www.xmule.org )
+  Copyright (C) 2003 Madcat ( madcat@xmule.org / http://www.xmule.org )
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -20,23 +20,49 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
+
+bool HexToDec(char x, char &res)
+{
+	if ( isdigit(x) ) {
+		res = x - '0';
+		return true;
+	} else if ( toupper(x)>='A' && toupper(x)<='F' ) {
+		res = toupper(x) - 'A' + 10;
+		return true;
+	} else {
+		return false;
+	}
+}
+
+void UnescapeURI(char *buf)
+{
+	char *outbuf = buf;
+	char c;
+	for ( ; c = *buf++; outbuf++) {
+		char digit1, digit2;
+		if ( (c == '%') && HexToDec(buf[0],digit1) && HexToDec(buf[1],digit2) ) {
+			*outbuf = digit1 * 16 + digit2;
+			buf+=2;
+		} else {
+			*outbuf = c;
+		}
+	}
+	*outbuf++ = '\0';
+}
 
 void AddLink(char *ed2klink)
 {
 FILE *ed2kfile;
 char filename[100];
 	
-	// First do some checking wether the link is correct.	
+	/* First do some checking wether the link is correct. */
 	if ((ed2klink[strlen(ed2klink)-35] != '|') && (ed2klink[strlen(ed2klink)-34] != '|')) {
 		printf("Invalid ED2K link.\nReason: Character before hash (34/35 chars before end) must be |\n");
 		return;
 	}
-	if ((ed2klink[strlen(ed2klink)-45] != '|') && (ed2klink[strlen(ed2klink)-44] != '|')) {
-		printf("Invalid ED2K link.\nReason: Character before numbers before hash (44/45 chars before end) must be |\n");
-		return;
-	}
 
-	// Link seemed ok, add it to file.
+	/* Link seemed ok, add it to file. */
 	sprintf(filename,"%s/.xMule/ED2KLinks",getenv("HOME"));
 	ed2kfile = fopen(filename,"a");
 	if (ed2kfile != NULL) {
@@ -50,18 +76,36 @@ char filename[100];
 
 int main(int argc, char *argv[])
 {
+	int result = 0;
 	for (int i=1;i<argc;i++) {
-		if (!strncmp(argv[i], "ed2k://|file|", 13) && (strlen(argv[i])>55)) {
-			AddLink(argv[i]);
-		} else if (!strncmp(argv[i], "--version", 9)) {
+		if ( !argv[i] ) {
+			continue;
+		}
+		char *param = strdup(argv[i]);
+		UnescapeURI(param);
+		if (!strncmp(param, "ed2k://|file|", 13) && (strlen(param)>55)) {
+			AddLink(param);
+		} else if (!strncmp(param, "--version", 9)) {
 			printf("xMule ED2K links parser v1.0\n");
+		} else if (!strncmp(param, "--help", 6)) {
+			printf("xMule ED2K links parser v1.0\n\n");
+			printf("Enter ed2k links as commandline arguments, and they will be saved into $HOME/.xMule/ED2KLinks\n");
+			printf("file, from where xMule will pick them up and add to download queue once per second.\n");
+			printf("Currently, only file links are supported.\n\n");
+			printf("Usage:\n");
+			printf("       --help          Prints this help.\n");
+			printf("       --version       Displays version info.\n");
+			printf("       ed2k://|file|   Sends ed2k link to $HOME/.xMule/ED2KLinks file.\n");
 		} else {
-			if (strncmp(argv[i], "ed2k://|file|", 13)) {
+			if (strncmp(param, "ed2k://|file|", 13)) {
 				printf("Invalid ED2K link.\nReason: First 13 characters don't match 'ed2k://|file|'\n");
 			}
-			if (strlen(argv[i])<=55) {
+			if (strlen(param)<=55) {
 				printf("Invalid ED2K Link.\nReason: Link length is below 55 characters.\n");
 			}
+			result = 1;
 		}
+		free(param);
 	}
+	return result;
 }
