@@ -44,7 +44,7 @@ void CFileStatistic::AddAccepted(){
 	theApp.sharedfiles->UpdateItem(fileParent);
 }
 	
-void CFileStatistic::AddTransferd(uint32 bytes){
+void CFileStatistic::AddTransferred(uint64 bytes){
 	transfered += bytes;
 	alltimetransfered += bytes;
 	theApp.knownfiles->transfered += bytes;
@@ -57,10 +57,16 @@ CKnownFile::CKnownFile(){
 	m_pszFileName = 0;
 	m_nFileSize = 0;
 	date = 0;
-	m_iPriority = PR_NORMAL;
 	m_iPermissions = PERM_ALL;
 	statistic.fileParent=this;
-	m_bAutoPriority = false ; //UAP Hunter
+	if (theApp.glob_prefs->GetNewAutoUp()){
+		m_iUpPriority = PR_HIGH;
+		m_bAutoUpPriority = true;
+	} else {
+		m_iUpPriority = PR_NORMAL;
+		m_bAutoUpPriority = false;
+	}
+	m_iQueuedCount = 0;
 	m_bCommentLoaded=false;
 	m_iRate=0;
 	m_strComment="";
@@ -77,6 +83,89 @@ CKnownFile::~CKnownFile(){
 //		delete[] filename;
 	if (directory)
 		delete[] directory;
+	m_AvailPartFrequency.RemoveAll();
+}
+
+CBarShader CKnownFile::s_ShareStatusBar(16);
+
+void CKnownFile::DrawShareStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat) {
+/*
+   DWORD crBoth; 
+   DWORD crNeither; 
+   DWORD crClientOnly; 
+   DWORD crPending;
+   DWORD crNextPending;
+
+   if(bFlat) { 
+		crBoth = RGB(0, 150, 0);
+		crNeither = RGB(224, 224, 224);
+		crClientOnly = RGB(0, 0, 0);
+		crPending = RGB(255,208,0);
+		crNextPending = RGB(255,255,100);
+   } else {
+		crBoth = RGB(0, 192, 0);
+		crNeither = RGB(240, 240, 240);
+		crClientOnly = RGB(104, 104, 104);
+		crPending = RGB(255, 208, 0);
+		crNextPending = RGB(255,255,100);
+   } 
+ */
+
+   s_ShareStatusBar.SetFileSize(GetFileSize()); 
+   s_ShareStatusBar.SetHeight(rect.GetHeight()); 
+   s_ShareStatusBar.SetWidth(rect.GetWidth()); 
+   s_ShareStatusBar.Fill(RGB(255,0,0));
+
+   if (!onlygreyrect && !m_AvailPartFrequency.IsEmpty()) {
+   	for (int i = 0;i != GetPartCount();i++)
+   		if(m_AvailPartFrequency[i] > 0 ){
+   			DWORD color = RGB(0, (210-(22*(m_AvailPartFrequency[i]
+-1)) <  0)? 0:210-(22*(m_AvailPartFrequency[i]-1)), 255);
+			s_ShareStatusBar.FillRange(PARTSIZE*(i),PARTSIZE
+*(i+1),color);
+		}
+   }
+   s_ShareStatusBar.Draw(dc, rect.GetLeft(), rect.GetTop(), bFlat);
+}
+
+void CKnownFile::NewAvailPartsInfo(){
+	// Cache part count
+	uint16 partcount = GetPartCount();
+
+	if(m_AvailPartFrequency.GetSize() < partcount)
+		m_AvailPartFrequency.SetSize(partcount);
+
+	// Reset part counters
+	for(int i = 0; i < partcount; i++){
+		m_AvailPartFrequency.Add(0);
+	}
+	CUpDownClient* cur_src;
+	if(this->IsPartFile())
+		cur_src = NULL;
+	
+	for (POSITION pos = m_ClientUploadList.GetHeadPosition(); pos != 0; ){
+
+		cur_src = m_ClientUploadList.GetNext(pos);
+		for (int i = 0; i != partcount; i++){
+			if (cur_src->IsUpPartAvailable(i))
+				m_AvailPartFrequency[i] +=1;
+		}
+	}
+	theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
+}
+
+void CKnownFile::AddUploadingClient(CUpDownClient* client){
+	POSITION pos = m_ClientUploadList.Find(client); // to be sure
+	if(pos == NULL){
+		m_ClientUploadList.AddTail(client);
+	}
+}
+
+void CKnownFile::RemoveUploadingClient(CUpDownClient* client){
+	POSITION pos = m_ClientUploadList.Find(client); // to be sure
+	if(pos != NULL){
+		m_ClientUploadList.RemoveAt(pos);
+	}
 }
 
 void CKnownFile::SetPath(char* path){
@@ -106,6 +195,9 @@ bool CKnownFile::CreateFromFile(char* in_directory,char* in_filename, volatile i
 	fseek(file,0,SEEK_END);
 	m_nFileSize=ftell(file);
 	fseek(file,curpos,SEEK_SET);
+	m_AvailPartFrequency.SetSize(GetPartCount());
+	for (uint32 i=0; i != GetPartCount(); i++)
+		m_AvailPartFrequency.Add(0);
 
 	// create hashset
 	uint32 togo = m_nFileSize;
@@ -200,6 +292,9 @@ bool CKnownFile::LoadTagsFromFile(CFile* file){
 			}
 			case FT_FILESIZE:{
 				m_nFileSize = newtag->tag->intvalue;
+				m_AvailPartFrequency.SetSize(GetPartCount());
+				for (uint32 i=0; i != GetPartCount(); i++)
+					m_AvailPartFrequency.Add(0);
 				delete newtag;
 				break;
 			}
@@ -218,8 +313,18 @@ bool CKnownFile::LoadTagsFromFile(CFile* file){
 				delete newtag;
 				break;
 			}
-			case FT_PRIORITY:{
-				m_iPriority = newtag->tag->intvalue;
+			case FT_OLDDLPRIORITY:	// for compatibility only
+			case FT_OLDULPRIORITY:	// for compatibility only
+			case FT_DLPRIORITY:	// for compatibility only
+			case FT_ULPRIORITY:{
+				uint8 autoprio = PR_AUTO;
+				m_iUpPriority = newtag->tag->intvalue;
+				if( m_iUpPriority == autoprio ){
+					m_iUpPriority = PR_HIGH;
+					m_bAutoUpPriority = true;
+				}
+				else
+					m_bAutoUpPriority = false;
 				delete newtag;
 				break;
 			}
@@ -262,7 +367,8 @@ bool CKnownFile::WriteToFile(FILE* file){
 	for (int i = 0; i != parts; i++)
 		fwrite(hashlist[i],16,1,file);
 	//tags
-	uint32 tagcount = taglist.GetCount()+7;
+#define NR_TAGS 10
+	uint32 tagcount = taglist.GetCount()+NR_TAGS;
 	// standard tags
 	fwrite(&tagcount,4,1,file);
 	CTag(FT_FILENAME,    m_pszFileName                   ).WriteTagToFile(file);
@@ -272,12 +378,16 @@ bool CKnownFile::WriteToFile(FILE* file){
 	CTag(FT_ATREQUESTED, statistic.GetAllTimeRequests()  ).WriteTagToFile(file);
 	CTag(FT_ATACCEPTED,  statistic.GetAllTimeAccepts()   ).WriteTagToFile(file);
 	// priority N permission
-	CTag(FT_PRIORITY,    m_iPriority                     ).WriteTagToFile(file);
+	CTag(FT_OLDDLPRIORITY,    m_iUpPriority              ).WriteTagToFile(file);
+	CTag(FT_OLDULPRIORITY,    m_iUpPriority              ).WriteTagToFile(file);
+	CTag(FT_ULPRIORITY,    m_iUpPriority                 ).WriteTagToFile(file);
+	CTag(FT_DLPRIORITY,    m_iUpPriority                 ).WriteTagToFile(file);	// for compatibility only
 	CTag(FT_PERMISSIONS, m_iPermissions                  ).WriteTagToFile(file);
 	//other tags
-	for (uint32 j = 0; j < tagcount-7;j++)
+	for (uint32 j = 0; j < tagcount-NR_TAGS;j++)
 		taglist[j]->WriteTagToFile(file);
 	return ferror(file);
+#undef NR_TAGS
 }
 
 void CKnownFile::CreateHashFromInput(FILE* file,CFile* file2, int Length, uchar* Output, uchar* in_string) {
@@ -442,7 +552,7 @@ void CAbstractFile::SetFileName(char* NewName)
 
 Packet*	CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 	CTypedPtrList<CPtrList, CUpDownClient*> srclist;
-	theApp.uploadqueue->FindSourcesForFileById(&srclist, forClient->reqfileid); //should we use "filehash"?
+	theApp.uploadqueue->FindSourcesForFileById(&srclist, forClient->GetUploadFileID()); //should we use "filehash"?
 
 	if(srclist.IsEmpty())
 		return 0;
@@ -450,7 +560,7 @@ Packet*	CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 	CMemFile data;
 	uint16 nCount = 0;
 
-	data.Write(forClient->reqfileid, 16);
+	data.Write(forClient->GetUploadFileID(), 16);
 	data.Write(&nCount, 2);
 
 	uint32 lastRequest = forClient->GetLastSrcReqTime();
@@ -471,6 +581,8 @@ Packet*	CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 			data.Write(&nPort, 2);
 			data.Write(&dwServerIP, 4);
 			data.Write(&nServerPort, 2);
+			if (forClient->GetSourceExchangeVersion() > 1)
+				data.Write(cur_src->GetUserHash(), 16);
 		}
 
 		srclist.RemoveAt(pos);
@@ -490,25 +602,29 @@ Packet*	CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient){
 }
 
 // Updates priority of file if autopriority is activated
-void CKnownFile::UpdateUploadAutoPriority(void)
+void CKnownFile::UpdateAutoUpPriority(void)
 {
-	if (this->IsAutoPrioritized()) {
-		if (!theApp.glob_prefs->GetNewAutoUp() || !this->IsPartFile()){
-			this->SetAutoPriority(false);
-			this->SetPriority(PR_NORMAL);
-			return;
-		}
+	if (!this->IsAutoUpPriority())
+		return;
 
-		CPartFile* partfile = (CPartFile*)this;
-
-		if (partfile->IsPartFile()) {
-			if (partfile->GetSourceCount() <= RARE_FILE)
-				this->SetPriority(PR_VERYHIGH);
-			else if (partfile->GetSourceCount() < RARE_FILE*25)
-				this->SetPriority(PR_HIGH);
-			else
-				this->SetPriority(PR_NORMAL);
+	if ( GetQueuedCount() > 20 ){
+		if ( GetUpPriority() != PR_LOW ){
+			SetUpPriority(PR_LOW);
+			theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
 		}
+		return;
+	}
+
+	if ( GetQueuedCount() > 1 ){
+		if ( GetUpPriority() != PR_NORMAL ){
+			SetUpPriority(PR_NORMAL);
+			theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
+		}
+		return;
+	}
+	if ( GetUpPriority() != PR_HIGH ){
+		SetUpPriority(PR_HIGH);
+		theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->UpdateItem(this);
 	}
 }
 
@@ -578,3 +694,9 @@ void CKnownFile::SetFileRate(int8 iNewRate){
   }
 } 
 
+void CKnownFile::SetUpPriority(uint8 iNewUpPriority, bool m_bsave){
+	m_iUpPriority = iNewUpPriority;
+	if( this->IsPartFile() && m_bsave )
+		((CPartFile*)this)->SavePartFile();
+}
+
