@@ -22,13 +22,13 @@
 #include "otherstructs.h"
 #include "packets.h"
 #include "types.h"
-#include "updownclient.h"
+//include "updownclient.h"
 //#include <afxcoll.h>
 //#include <afxtempl.h>
 //#include <afxcmn.h>
 #include "CFile.h"
 #include "wx/dynarray.h"
-
+#include "BarShader.h"
 
 class CFileStatistic{
 	friend class CKnownFile;
@@ -36,10 +36,10 @@ public:
 	CFileStatistic()					{requested = transfered = accepted = alltimerequested= alltimetransfered = alltimeaccepted = 0;}
 	void	AddRequest();
 	void	AddAccepted();
-	void	AddTransferd(uint32 bytes);
+	void	AddTransferred(uint64 bytes);
 	uint16	GetRequests()				{return requested;}
 	uint16	GetAccepts()				{return accepted;}
-	uint32	GetTransfered()				{return transfered;}
+	uint64	GetTransfered()				{return transfered;}
 	uint16	GetAllTimeRequests()		{return alltimerequested;}
 	uint16	GetAllTimeAccepts()			{return alltimeaccepted;}
 	uint64	GetAllTimeTransfered()		{return alltimetransfered;}
@@ -47,7 +47,7 @@ public:
 
 private:
 	uint16 requested;
-	uint32 transfered;
+	uint64 transfered;
 	uint16 accepted;
 	uint32 alltimerequested;
 	uint64 alltimetransfered;
@@ -116,18 +116,24 @@ public:
 	inline uint16	GetPartCount()	{return m_iPartCount>0? m_iPartCount:   (m_iPartCount = ((m_nFileSize+(PARTSIZE -1)) / PARTSIZE));}								 
 	uint32	date;
 	// file upload priority
-	uint8	m_iPriority;
-	uint8	GetPriority(void)		{return m_iPriority;};
-	void	SetPriority(uint8 iNewPriority) {m_iPriority = iNewPriority;};
-	void    UpdateUploadAutoPriority(void) ;	//UAP Hunter
-	bool	IsAutoPrioritized()		{ return m_bAutoPriority ; } //UAP Hunter
-	void	SetAutoPriority(bool newAutoPriority) { this->m_bAutoPriority = newAutoPriority ; } //UAP Hunter
+	uint8	GetUpPriority()			{return m_iUpPriority;}
+	void	SetUpPriority(uint8 newUpPriority, bool bSave=true);
+	bool	IsAutoUpPriority()		{return m_bAutoUpPriority;}
+	void	SetAutoUpPriority(bool flag)	{m_bAutoUpPriority = flag;}
+	void	UpdateAutoUpPriority();
+	void	AddQueuedCount() {m_iQueuedCount++; UpdateAutoUpPriority();};
+	void	SubQueuedCount() {if(m_iQueuedCount) m_iQueuedCount--; UpdateAutoUpPriority();}
+	uint32	GetQueuedCount() {return m_iQueuedCount;}
+
 	// shared file view permissions (all, only friends, no one)
-	uint8	m_iPermissions;
 	uint8	GetPermissions(void)	{ return m_iPermissions; };
 	void	SetPermissions(uint8 iNewPermissions) {m_iPermissions = iNewPermissions;};
 
 	bool	LoadHashsetFromFile(CFile* file, bool checkhash);
+	void	AddUploadingClient(CUpDownClient* client);
+	void	RemoveUploadingClient(CUpDownClient* client);
+	void	NewAvailPartsInfo();
+	void	DrawShareStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool bFlat);
 
 	CFileStatistic statistic;
 	// comment 
@@ -152,9 +158,16 @@ protected:
 
 private:
 	void	CreateHashFromInput(FILE* file,CFile* file2, int Length, uchar* Output, uchar* = 0);
-	bool	m_bAutoPriority ; //UAP Hunter
 	bool	m_bCommentLoaded;
 	uint16	m_iPartCount;
+	uint8	m_iUpPriority;
+	uint8	m_iPermissions;
+	bool	m_bAutoUpPriority;
+	uint32	m_iQueuedCount;
+	static	CBarShader s_ShareStatusBar;
+
+	CTypedPtrList<CPtrList, CUpDownClient*> m_ClientUploadList;
+	CArray<uint16,uint16> m_AvailPartFrequency;
 };
 
 // permission values for shared files
