@@ -195,11 +195,11 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	      theApp.downloadqueue->CheckAndAddKnownSource((CPartFile*)reqfile,client);
 	  
 	  // check to see if this is a new file they are asking for
-	  if(memcmp(client->reqfileid, packet, 16) != 0)
+	  if(memcmp(client->GetUploadFileID(), reqfileid, 16) != 0)
 	    client->SetCommentDirty();
 	  
 	  // send filename etc
-	  memcpy(client->reqfileid,packet,16);
+	  client->SetUploadFileID(reqfileid);
 	  CMemFile* data = new CMemFile();
 	  data->Write(reqfile->GetFileHash(),16);
 	  uint16 namelength = (uint16)strlen(reqfile->GetFileName());
@@ -375,11 +375,11 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	      theApp.downloadqueue->CheckAndAddKnownSource((CPartFile*)reqfile,client);
 	  
 	  // check to see if this is a new file they are asking for
-	  if(memcmp(client->reqfileid, packet, 16) != 0)
+	  if(memcmp(client->GetUploadFileID(), packet, 16) != 0)
 	    client->SetCommentDirty();
 	  
 	  //send filestatus
-	  memcpy(client->reqfileid,packet,16);
+	  client->SetUploadFileID((uchar*)packet);
 	  CMemFile* data = new CMemFile();
 	  data->Write(reqfile->GetFileHash(),16);
 	  if (reqfile->IsPartFile())
@@ -463,6 +463,136 @@ bool CClientReqSocket::ProcessPacket(char* packet, uint32 size, uint8 opcode){
 	client->ProcessSharedFileList(packet,size);
 	break;
       }
+      case OP_ASKSHAREDDIRS:{
+        theApp.downloadqueue->AddDownDataOverheadOther(size);
+        if (theApp.glob_prefs->CanSeeShares()==0 || (theApp.glob_prefs->CanSeeShares()==1 && client->IsFriend())){
+        	theApp.xmuledlg->AddLogLine(true,_("User %s (%u) requested your shareddirectories-list -> %s"),client->GetUserName(),client->GetUserID(),GetResString(IDS_ACCEPTED).GetBuffer() );
+
+		CSafeMemFile tempfile(80);
+		uint32 uDirs = theApp.glob_prefs->shareddir_list.GetCount();
+		tempfile.Write(&uDirs, 4);
+
+		for (uint32 iDir=0; iDir < uDirs; iDir++)
+		{
+			CString strDir(theApp.glob_prefs->shareddir_list[iDir]);
+			uint16 cnt = strDir.GetLength();
+			tempfile.Write(&cnt, 2);
+			tempfile.Write(strDir.GetData(), cnt);
+		}
+		// and the incoming folders
+		for (int ix=0;ix<theApp.glob_prefs->GetCatCount();ix++) {
+			CString strDir;
+			strDir=CString(theApp.glob_prefs->GetCategory(ix)->incomingpath);
+			uint16 cnt = strDir.GetLength();
+			tempfile.Write(&cnt, 2);
+			tempfile.Write(strDir.GetData(), cnt);
+		}
+		Packet* replypacket = new Packet(&tempfile);
+		replypacket->opcode = OP_ASKSHAREDDIRSANS;
+		theApp.uploadqueue->AddUpDataOverheadOther(replypacket->size);
+		SendPacket(replypacket, true, true);
+	} else {
+		theApp.xmuledlg->AddLogLine(true,_("User %s (%u) requested your shareddirectories-list -> %s"),client->GetUserName(),client->GetUserID(),GetResString(IDS_DENIED).GetData() );
+		Packet* replypacket = new Packet(OP_ASKSHAREDDENIEDANS, 0);
+		theApp.uploadqueue->AddUpDataOverheadOther(replypacket->size);
+		SendPacket(replypacket, true, true);
+	}
+	break;
+      }
+      case OP_ASKSHAREDFILESDIR:{
+      	theApp.downloadqueue->AddDownDataOverheadOther(size);
+      	CSafeMemFile data((uchar*)packet, size, 0);
+      	if ( size < 2 )
+      		throw CString("Short ASKSHAREDFILESDIR packet");
+      	uint16 cnt;
+      	data.Read(&cnt, 2);
+      	if ( (size-2) < cnt )
+      		throw CString("Short ASKSHAREDFILESDIR packet");
+      	char *strReqDir = new char[cnt+1];
+      	if ( data.Read(strReqDir, cnt) )
+      	strReqDir[cnt]=0;
+      	if (theApp.glob_prefs->CanSeeShares()==0 || (theApp.glob_prefs->CanSeeShares()==1 && client->IsFriend())){
+		theApp.xmuledlg->AddLogLine(true,_("User %s (%u) requested your sharedfiles-list for directory %s -> %s"),client->GetUserName(),client->GetUserID(),strReqDir,GetResString(IDS_ACCEPTED).GetData() );
+
+		CTypedPtrList<CPtrList, CKnownFile*> list;
+		theApp.sharedfiles->GetSharedFilesByDirectory(strReqDir,list);
+
+		CSafeMemFile tempfile(80);
+		uint16 cnt = strlen(strReqDir);
+		tempfile.Write(&cnt, 2);
+		tempfile.Write(strReqDir, cnt);
+		uint32 uFiles = list.GetCount();
+		tempfile.Write(&uFiles, 4);
+		while (list.GetCount()){
+			theApp.sharedfiles->CreateOfferedFilePacket(list.GetHead(), &tempfile);
+			list.RemoveHead();
+		}
+
+		Packet* replypacket = new Packet(&tempfile);
+		replypacket->opcode = OP_ASKSHAREDFILESDIRANS;
+		theApp.uploadqueue->AddUpDataOverheadOther(replypacket->size);
+		SendPacket(replypacket, true, true);
+	} else {
+		theApp.xmuledlg->AddLogLine(true,_("User %s (%u) requested your sharedfiles-list for directory %s -> %s"),client->GetUserName(),client->GetUserID(),strReqDir,GetResString(IDS_DENIED).GetData() );
+		Packet* replypacket = new Packet(OP_ASKSHAREDDENIEDANS, 0);
+		theApp.uploadqueue->AddUpDataOverheadOther(replypacket->size);
+		SendPacket(replypacket, true, true);
+	}
+	delete[] strReqDir;
+	break;
+      }
+      case OP_ASKSHAREDDIRSANS:
+	theApp.downloadqueue->AddDownDataOverheadOther(size);
+	if (client->GetFileListRequested() == 1){
+		CSafeMemFile data((uchar*)packet, size, 0);
+		uint32 uDirs;
+		if ( 4 != data.Read(&uDirs, 4) )
+			throw CString("Short SHAREDDIRSANS packet reading the number of directories");
+		for ( uint32 iDir = 0; iDir != uDirs; iDir++ )
+		{
+			uint16 cnt;
+			data.Read(&cnt, 2);
+			if ( (size-4) < cnt )
+				throw CString("Short SHAREDDIRSANS packet reading the directory name");
+			char *strDir = new char[cnt+1];
+			data.Read(strDir,cnt);
+			strDir[cnt] = 0;
+			theApp.xmuledlg->AddLogLine(true,_("User %s (%u) shares directory %s"),client->GetUserName(),client->GetUserID(),strDir);
+			CSafeMemFile tempfile(80);
+			cnt = strlen(strDir);
+			tempfile.Write(&cnt, 2);
+			tempfile.Write(strDir, cnt);
+			Packet* replypacket = new Packet(&tempfile);
+			replypacket->opcode = OP_ASKSHAREDFILESDIR;
+			theApp.uploadqueue->AddUpDataOverheadOther(replypacket->size);
+			SendPacket(replypacket, true, true);
+			client->SetFileListRequested(iDir+1);
+			delete[] strDir;
+		}
+	}
+	break;
+      case OP_ASKSHAREDFILESDIRANS:{
+      	theApp.downloadqueue->AddDownDataOverheadOther(size);
+      	if (client->GetFileListRequested() > 0){
+      		CSafeMemFile data((uchar*)packet, size, 0);
+      		uint16 cnt;
+      		if ( 2 != data.Read(&cnt, 2) )
+			throw CString("Short SHAREDFILESDIRANS packet reading the length of the directory name");
+		if ( (size-2) < cnt )
+			throw CString("Short SHAREDFILESDIRANS packet reading the directory name");
+		char *strDir = new char[cnt+1];
+		data.Read(strDir, cnt);
+		strDir[cnt] = 0;
+		theApp.xmuledlg->AddLogLine(true,"User %s (%u) sent sharedfiles-list for directory %s",client->GetUserName(),client->GetUserID(),strDir);
+		delete[] strDir;
+		client->ProcessSharedFileList(packet + data.GetPosition(), size - data.GetPosition());
+      	}
+      	break;
+      }
+      case OP_ASKSHAREDDENIEDANS:
+        theApp.downloadqueue->AddDownDataOverheadOther(size);
+        theApp.xmuledlg->AddLogLine(true,_("User %s (%u) denied access to shareddirectories/files-list"),client->GetUserName(),client->GetUserID());
+        break;
       default:
 	theApp.downloadqueue->AddDownDataOverheadOther(size);
 	theApp.xmuledlg->AddDebugLogLine(false,"unknown opcode: %i %x",opcode,opcode);
@@ -582,7 +712,7 @@ bool CClientReqSocket::ProcessExtPacket(char* packet, uint32 size, uint8 opcode)
 							//and set the file's last answer time
 							((CPartFile*)file)->SetLastAnsweredTime();
 	
-							((CPartFile*)file)->AddClientSources(&data);
+							((CPartFile*)file)->AddClientSources(&data, client->GetSourceExchangeVersion());
 						}
 					}
 				}
