@@ -25,6 +25,29 @@
 #include "EMSocket.h"
 
 #include <wx/socket.h>
+#include <wx/hashmap.h>
+#include <string.h>
+
+class WXDLLEXPORT MyIntegerHash
+{
+public:
+    MyIntegerHash() { }
+    uint64 operator()( uint64 x ) const { return x; }
+
+    MyIntegerHash& operator=(const MyIntegerHash&) { return *this; }
+};
+
+class WXDLLEXPORT MyIntegerEqual
+{
+public:
+    MyIntegerEqual() { }
+    bool operator()( uint64 a, uint64 b ) const { return a == b; }
+
+    MyIntegerEqual& operator=(const MyIntegerEqual&) { return *this; }
+};
+
+WX_DECLARE_HASH_MAP(uint64, uint32, MyIntegerHash, MyIntegerEqual, MyHashMap1);
+WX_DECLARE_HASH_MAP(uint64, uint64, MyIntegerHash, MyIntegerEqual, MyHashMap2);
 
 class CUpDownClient;
 class CPacket;
@@ -34,43 +57,44 @@ class CTimerWnd;
 
 class CClientReqSocket : public CEMSocket
 {
-  friend class CClientSocket;
+friend class CClientSocket;
 
-  DECLARE_DYNAMIC_CLASS(CClientReqSocket)
-    
-    CClientReqSocket(); /*{};*/
- public:
+	DECLARE_DYNAMIC_CLASS(CClientReqSocket)
 
-  CClientReqSocket(CPreferences* in_prefs, CUpDownClient* in_client = 0);	
-  ~CClientReqSocket();
-  void	Disconnect();
-  
- void	ResetTimeOutTimer();
-  bool	CheckTimeOut();
-  void	Safe_Delete();
-  
-  long	deletethis;
+	CClientReqSocket(); /*{};*/
+public:
 
-  bool	Create();
-  void		 OnClose(int nErrorCode);
-  void		 OnSend(int nErrorCode);
-  void		 OnReceive(int nErrorCode);
-  void		 OnError(int nErrorCode);
-  virtual	void OnInit();
-  virtual bool Close(); /*	{return wxSocketBase::Close();}*/
+	CClientReqSocket(CPreferences* in_prefs, CUpDownClient* in_client = 0);	
+	~CClientReqSocket();
+	void		Disconnect();
 
-  protected:
-  void		 PacketReceived(Packet* packet);
-  private:
-  void	Delete_Timed();
-  bool	ProcessPacket(char* packet, uint32 size,uint8 opcode);
-  bool	ProcessExtPacket(char* packet, uint32 size,uint8 opcode);
+	void		ResetTimeOutTimer();
+	bool		CheckTimeOut();
+	void		Safe_Delete();
 
- public:
-  uint32	timeout_timer;
-  uint32	deltimer;  
-  CUpDownClient*	client;
-  CPreferences* app_prefs;
+	long		deletethis;
+
+	bool		Create();
+	void		OnClose(int nErrorCode);
+	void		OnSend(int nErrorCode);
+	void		OnReceive(int nErrorCode);
+	void		OnError(int nErrorCode);
+	virtual	void OnInit();
+	virtual	bool Close(); /*	{return wxSocketBase::Close();}*/
+	
+	uint32		timeout_timer;
+	uint32		deltimer;  
+	bool		hotrank;
+	CUpDownClient*	client;
+	CPreferences* 	app_prefs;
+
+
+protected:
+	void		 PacketReceived(Packet* packet);
+private:
+	void		Delete_Timed();
+	bool		ProcessPacket(char* packet, uint32 size,uint8 opcode);
+	bool		ProcessExtPacket(char* packet, uint32 size,uint8 opcode);
 };
 
 #include <wx/list.h>
@@ -111,6 +135,11 @@ private:
 	wxIPV4address happyCompiler;
 	uint16	m_ConnectionStates[3];
 	uint16	m_nPeningConnections;
+
+public:
+	MyHashMap1 offensecounter;
+	MyHashMap2 hashbase;  
+
 };
 
 
