@@ -46,9 +46,6 @@
 #include "resource.h"
 #include <wx/filename.h>
 
-WX_DEFINE_LIST(VoidList);
-WX_DEFINE_LIST(stringList);
-
 #define ELEMENT_COUNT(X) (sizeof(X) / sizeof(X[0]))
 #define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
 
@@ -62,8 +59,6 @@ WX_DEFINE_LIST(stringList);
 #define MAX_PATH 2048
 #endif
 
-extern int sprintf(char *__restrict __s,__const char*__restrict __format,...) __attribute__ ((__format__ (__printf__, 2,3)));
-
 #ifdef __FreeBSD__
 extern long long atoll(char *s);
 #endif /* __FreeBSD__ */
@@ -125,7 +120,7 @@ CPreferences::CPreferences(){
 				memcpy(&prefs->userhash,&prefsImport20b->userhash,16);
 				memcpy(&prefs->incomingdir,&prefsImport20b->incomingdir,510);
 				memcpy(&prefs->tempdir,&prefsImport20b->tempdir,510);
-				sprintf(prefs->nick,prefsImport20b->nick);
+				sprintf(prefs->nick,"%s", prefsImport20b->nick);
 
 				prefs->totalDownloadedBytes=prefsImport20b->totalDownloadedBytes;
 				prefs->totalUploadedBytes=prefsImport20b->totalUploadedBytes;
@@ -139,7 +134,7 @@ CPreferences::CPreferences(){
 				memcpy(&prefs->userhash,&prefsImport20a->userhash,16);
 				memcpy(&prefs->incomingdir,&prefsImport20a->incomingdir,510);
 				memcpy(&prefs->tempdir,&prefsImport20a->tempdir,510);
-				sprintf(prefs->nick,prefsImport20a->nick);
+				sprintf(prefs->nick,"%s", prefsImport20a->nick);
 
 				prefs->totalDownloadedBytes=prefsImport20a->totalDownloaded;
 				prefs->totalUploadedBytes=prefsImport20a->totalUploaded;
@@ -156,7 +151,7 @@ CPreferences::CPreferences(){
 					memcpy(&prefs->userhash,&userhash,16);
 				} else {memcpy(&prefs->userhash,&prefsImport19c->userhash,16);}
 				memcpy(&prefs->incomingdir,&prefsImport19c->incomingdir,510);memcpy(&prefs->tempdir,&prefsImport19c->tempdir,510);
-				sprintf(prefs->nick,prefsImport19c->nick);
+				sprintf(prefs->nick,"%s",prefsImport19c->nick);
 			}
  		} else {
 			memcpy(&prefs->userhash,&prefsExt->userhash,16);
@@ -231,7 +226,7 @@ CPreferences::CPreferences(){
 		mkdir(prefs->tempdir,0777);
 	}
 #endif
-	if (((int*)prefs->userhash[0]) == 0 && ((int*)prefs->userhash[1]) == 0 && ((int*)prefs->userhash[2]) == 0 && ((int*)prefs->userhash[3]) == 0)
+	if (((int*)prefs->userhash)[0] == 0 && ((int*)prefs->userhash)[1] == 0 && ((int*)prefs->userhash)[2] == 0 && ((int*)prefs->userhash)[3] == 0)
 		CreateUserHash();
 }
 
@@ -251,10 +246,7 @@ void CPreferences::SetStandartValues(){
 }
 
 uint16 CPreferences::GetMaxDownload(){
-	//dont be a Lam3r :)
-	if( GetMaxUpload() < 4 )
-		return (( (GetMaxUpload() < 10) && (GetMaxUpload()*3 < prefs->maxdownload) )? GetMaxUpload()*3 : prefs->maxdownload);
-	return (( (GetMaxUpload() < 10) && (GetMaxUpload()*4 < prefs->maxdownload) )? GetMaxUpload()*4 : prefs->maxdownload);
+	return prefs->maxdownload;
 }
 
 bool CPreferences::Save(){
@@ -489,7 +481,7 @@ void CPreferences::SavePreferences(){
 	delete[] fullpath;
 	fullpath=NULL;
 	//---
-	ini.WriteString("AppVersion", CURRENT_VERSION_LONG);
+	ini.WriteString("AppVersion", PACKAGE_STRING);
 	//---
 
 	buffer.Format("%s",prefs->nick);
@@ -537,7 +529,7 @@ void CPreferences::SavePreferences(){
 	ini.WriteBool("BeepOnError",prefs->beepOnError);
 	ini.WriteBool("ConfirmExit",prefs->confirmExit);
 	ini.WriteBool("FilterBadIPs",prefs->filterBadIP);
-    ini.WriteBool("Autoconnect",prefs->autoconnect);
+	ini.WriteBool("Autoconnect",prefs->autoconnect);
 	ini.WriteBool("OnlineSignature",prefs->onlineSig);
 	ini.WriteBool("StartupMinimized",prefs->startMinimized);
 	ini.WriteBool("SafeServerConnect",prefs->safeServerConnect);
@@ -546,10 +538,10 @@ void CPreferences::SavePreferences(){
 	ini.WriteBool("WatchClipboard4ED2kFilelinks",prefs->watchclipboard);
 
 	// Barry - New properties...
-    ini.WriteBool("AutoConnectStaticOnly", prefs->autoconnectstaticonly);  
+	ini.WriteBool("AutoConnectStaticOnly", prefs->autoconnectstaticonly);  
 	ini.WriteBool("AutoTakeED2KLinks", prefs->autotakeed2klinks);  
-    ini.WriteBool("AddNewFilesPaused", prefs->addnewfilespaused);  
-    ini.WriteInt ("3DDepth", prefs->depth3D);  
+	ini.WriteBool("AddNewFilesPaused", prefs->addnewfilespaused);  
+	ini.WriteInt ("3DDepth", prefs->depth3D);  
 
 	ini.WriteBool("NotifyOnDownload",prefs->useDownloadNotifier); // Added by enkeyDEV
 	ini.WriteBool("NotifyOnChat",prefs->useChatNotifier);		  
@@ -595,6 +587,7 @@ void CPreferences::SavePreferences(){
 	ini.WriteInt("QueueSizePref", prefs->m_iQueueSize);
 	ini.WriteBool("DAPPref", prefs->m_bDAP);
 	ini.WriteBool("UAPPref", prefs->m_bUAP);
+	ini.WriteInt("AllcatType",prefs->allcatType);
 	ini.WriteBool("ShowAllNotCats", prefs->showAllNotCats);
 	ini.WriteBool("FilterServersByIP",prefs->filterserverbyip);
 	ini.WriteBool("DisableKnownClientList",prefs->m_bDisableKnownClientList);
@@ -682,20 +675,20 @@ void CPreferences::SavePreferences(){
 	ini.WriteInt("ProxyType",prefs->proxy.type,"Proxy");
 
 	CString buffer2;
-	for (int i=0;i<15;i++) {
-		buffer.Format("%I64Lu",GetStatsColor(i));
+	for (int i=0;i<13;i++) {
+		buffer.Format("%lu",(unsigned long)GetStatsColor(i));
 		buffer2.Format("StatColor%i",i);
-		ini.WriteString(buffer2,buffer);
+		ini.WriteString(buffer2,buffer,"eMule");
 	}
 
-	buffer.Format("%I64Lu",prefs->totalDownloadedBytes);
+	buffer.Format("%llu",(unsigned long long)prefs->totalDownloadedBytes);
 	ini.WriteString("TotalDownloadedBytes",buffer ,"Statistics");
 
-	buffer.Format("%I64Lu",prefs->totalUploadedBytes);
+	buffer.Format("%llu",(unsigned long long)prefs->totalUploadedBytes);
 	ini.WriteString("TotalUploadedBytes",buffer ,"Statistics");
 
-	    // my own :)
-    ini.WriteInt("DesktopMode",prefs->desktopMode);
+	// my own :)
+	ini.WriteInt("DesktopMode",prefs->desktopMode);
 
 
 	// Web Server
@@ -707,202 +700,13 @@ void CPreferences::SavePreferences(){
 	ini.WriteInt("PageRefreshTime", prefs->m_nWebPageRefresh);
 	ini.WriteBool("UseLowRightsUser", prefs->m_bWebLowEnabled);
 	
-#if 0	
-	CString buffer;
-	char* fullpath = new char[strlen(appdir)+MAX_PATH]; // i_a
-	sprintf(fullpath,"%spreferences.ini",appdir);
-	
-	CIni ini( fullpath, "eMule" );
-
-	delete[] fullpath;
-	fullpath=NULL;
-
-	//---
-	ini.WriteString("AppVersion", CURRENT_VERSION_LONG);
-	//---
-
-	buffer.Format("%s",prefs->nick);
-	ini.WriteString("Nick",buffer);
-
-	buffer.Format("%s",prefs->incomingdir);
-	ini.WriteString("IncomingDir",buffer );
-
-	buffer.Format("%s",prefs->tempdir);
-	ini.WriteString("TempDir",buffer );
-
-	ini.WriteInt("MaxUpload",prefs->maxupload);
-	ini.WriteInt("MaxDownload",prefs->maxdownload);
-	ini.WriteInt("MaxConnections",prefs->maxconnections);
-	ini.WriteInt("RemoveDeadServer",prefs->deadserver);
-	ini.WriteInt("Port",prefs->port);
-	ini.WriteInt("UDPPort",prefs->udpport);
-	ini.WriteInt("MaxSourcesPerFile",prefs->maxsourceperfile );
-	ini.WriteWORD("Language",prefs->languageID);
-	ini.WriteInt("SeeShare",prefs->m_iSeeShares);
-	ini.WriteInt("ToolTipDelay",prefs->m_iToolDelayTime);
-	ini.WriteInt("StatGraphsInterval",prefs->trafficOMeterInterval);
-	ini.WriteInt("StatsInterval",prefs->statsInterval);
-	ini.WriteInt("DownloadCapacity",prefs->maxGraphDownloadRate);
-	ini.WriteInt("UploadCapacity",prefs->maxGraphUploadRate);
-	ini.WriteInt("DeadServerRetry",prefs->deadserverretries);
-	ini.WriteInt("SplitterbarPosition",prefs->splitterbarPosition+2);
-	ini.WriteInt("VariousStatisticsMaxValue",prefs->statsMax);
-	ini.WriteInt("StatsAverageMinutes",prefs->statsAverageMinutes);
-	ini.WriteInt("MaxConnectionsPerFiveSeconds",prefs->MaxConperFive);
-	ini.WriteInt("Check4NewVersionDelay",prefs->versioncheckdays);
-
-	ini.WriteBool("Reconnect",prefs->reconnect);
-	ini.WriteBool("Scoresystem",prefs->scorsystem);
-	ini.WriteBool("ICH",prefs->ICH);
-	ini.WriteBool("Serverlist",prefs->autoserverlist);
-	ini.WriteBool("UpdateNotify",prefs->updatenotify);
-	ini.WriteBool("MinToTray",prefs->mintotray);
-	ini.WriteBool("AddServersFromServer",prefs->addserversfromserver);
-	ini.WriteBool("AddServersFromClient",prefs->addserversfromclient);
-	ini.WriteBool("Splashscreen",prefs->splashscreen);
-	ini.WriteBool("BringToFront",prefs->bringtoforeground);
-	ini.WriteBool("TransferDoubleClick",prefs->transferDoubleclick);
-	ini.WriteBool("BeepOnError",prefs->beepOnError);
-	ini.WriteBool("ConfirmExit",prefs->confirmExit);
-	ini.WriteBool("FilterBadIPs",prefs->filerBadIP);
-    ini.WriteBool("Autoconnect",prefs->autoconnect);
-	ini.WriteBool("OnlineSignature",prefs->onlineSig);
-	ini.WriteBool("StartupMinimized",prefs->startMinimized);
-	ini.WriteBool("SafeServerConnect",prefs->safeServerConnect);
-	ini.WriteBool("ShowRatesOnTitle",prefs->showRatesInTitle);
-
-	// Barry - New properties...
-    ini.WriteBool("AutoConnectStaticOnly", prefs->autoconnectstaticonly);  
-	ini.WriteBool("AutoTakeED2KLinks", prefs->autotakeed2klinks);  
-    ini.WriteBool("AddNewFilesPaused", prefs->addnewfilespaused);  
-    ini.WriteInt ("3DDepth", prefs->depth3D);  
-
-    // my own :)
-    ini.WriteInt("DesktopMode",prefs->desktopMode);
-
-	ini.WriteBool("UAP", prefs->UAP) ;
-	ini.WriteBool("NotifyOnDownload",prefs->useDownloadNotifier); // Added by enkeyDEV
-	ini.WriteBool("NotifyOnChat",prefs->useChatNotifier);		  
-	ini.WriteBool("NotifyOnLog",prefs->useLogNotifier);
-	ini.WriteBool("NotifierUseSound",prefs->useSoundInNotifier);
-	ini.WriteBool("NotifierPopEveryChatMessage",prefs->notifierPopsEveryChatMsg);
-	ini.WriteBool("NotifierPopNewVersion",prefs->notifierNewVersion);
-
-	buffer.Format("%s",prefs->notifierSoundFilePath);
-	ini.WriteString("NotifierSoundPath",buffer);
-
-	ini.WriteString("TxtEditor",prefs->TxtEditor);
-	ini.WriteString("VideoPlayer",prefs->VideoPlayer);
-	ini.WriteString("MessageFilter",prefs->messageFilter);
-
-	ini.WriteString("DefaultIRCServer",prefs->m_sircserver);
-	ini.WriteString("IRCNick",prefs->m_sircnick);
-	ini.WriteBool("IRCAddTimestamp", prefs->m_bircaddtimestamp);
-	ini.WriteString("IRCFilterName", prefs->m_sircchannamefilter);
-	ini.WriteInt("IRCFilterUser", prefs->m_iircchanneluserfilter);
-	ini.WriteBool("IRCUseFilter", prefs->m_bircusechanfilter);
-	ini.WriteString("IRCPerformString", prefs->m_sircperformstring);
-	ini.WriteBool("IRCUsePerform", prefs->m_bircuseperform);
-	ini.WriteBool("IRCListOnConnect", prefs->m_birclistonconnect);
-	ini.WriteBool("IRCAcceptLinks", prefs->m_bircacceptlinks);
-	ini.WriteBool("IRCIgnoreInfoMessage", prefs->m_bircignoreinfomessage);
-	ini.WriteBool("IRCIgnoreEmuleProtoInfoMessage", prefs->m_bircignoreemuleprotoinfomessage);
-	ini.WriteBool("NotifyOnImportantError", prefs->notifierImportantError);
-	ini.WriteBool("SmartIdCheck", prefs->smartidcheck);
-	ini.WriteBool("Verbose", prefs->m_bVerbose);
-	ini.WriteBool("PreviewPrio", prefs->m_bpreviewprio);
-	ini.WriteBool("UpdateQueueListPref", prefs->m_bupdatequeuelist);
-	ini.WriteBool("ManualHighPrio", prefs->m_bmanualhighprio);
-	ini.WriteBool("FullChunkTransfers", prefs->m_btransferfullchunks);
-	ini.WriteBool("StartNextFile", prefs->m_bstartnextfile);
-	ini.WriteBool("ShowOverhead", prefs->m_bshowoverhead);
-	ini.WriteBool("VideoPreviewBackupped", prefs->moviePreviewBackup);
-	ini.WriteInt("FileBufferSizePref", prefs->m_iFileBufferSize);
-	ini.WriteInt("QueueSizePref", prefs->m_iQueueSize);
-	
-	ini.WriteInt("VersionCheckLastAutomatic", prefs->versioncheckLastAutomatic);
-
-	ini.SerGet(false, prefs->downloadColumnWidths,
-		ELEMENT_COUNT(prefs->downloadColumnWidths), "DownloadColumnWidths");
-	ini.SerGet(false, prefs->downloadColumnHidden,
-		ELEMENT_COUNT(prefs->downloadColumnHidden), "DownloadColumnHidden");
-	ini.SerGet(false, prefs->downloadColumnOrder,
-		ELEMENT_COUNT(prefs->downloadColumnOrder), "DownloadColumnOrder");
-	ini.SerGet(false, prefs->uploadColumnWidths,
-		ELEMENT_COUNT(prefs->uploadColumnWidths), "UploadColumnWidths");
-	ini.SerGet(false, prefs->uploadColumnHidden,
-		ELEMENT_COUNT(prefs->uploadColumnHidden), "UploadColumnHidden");
-	ini.SerGet(false, prefs->uploadColumnOrder,
-		ELEMENT_COUNT(prefs->uploadColumnOrder), "UploadColumnOrder");
-	ini.SerGet(false, prefs->queueColumnWidths,
-		ELEMENT_COUNT(prefs->queueColumnWidths), "QueueColumnWidths");
-	ini.SerGet(false, prefs->queueColumnHidden,
-		ELEMENT_COUNT(prefs->queueColumnHidden), "QueueColumnHidden");
-	ini.SerGet(false, prefs->queueColumnOrder,
-		ELEMENT_COUNT(prefs->queueColumnOrder), "QueueColumnOrder");
-	ini.SerGet(false, prefs->searchColumnWidths,
-		ELEMENT_COUNT(prefs->searchColumnWidths), "SearchColumnWidths");
-	ini.SerGet(false, prefs->searchColumnHidden,
-		ELEMENT_COUNT(prefs->searchColumnHidden), "SearchColumnHidden");
-	ini.SerGet(false, prefs->searchColumnOrder,
-		ELEMENT_COUNT(prefs->searchColumnOrder), "SearchColumnOrder");
-	ini.SerGet(false, prefs->sharedColumnWidths,
-		ELEMENT_COUNT(prefs->sharedColumnWidths), "SharedColumnWidths");
-	ini.SerGet(false, prefs->sharedColumnHidden,
-		ELEMENT_COUNT(prefs->sharedColumnHidden), "SharedColumnHidden");
-	ini.SerGet(false, prefs->sharedColumnOrder,
-		ELEMENT_COUNT(prefs->sharedColumnOrder), "SharedColumnOrder");
-	ini.SerGet(false, prefs->serverColumnWidths,
-		ELEMENT_COUNT(prefs->serverColumnWidths), "ServerColumnWidths");
-	ini.SerGet(false, prefs->serverColumnHidden,
-		ELEMENT_COUNT(prefs->serverColumnHidden), "ServerColumnHidden");
-	ini.SerGet(false, prefs->serverColumnOrder,
-		ELEMENT_COUNT(prefs->serverColumnOrder), "ServerColumnOrder");
-
-	// Barry - Provide a mechanism for all tables to store/retrieve sort order
-	ini.WriteInt("TableSortItemDownload", prefs->tableSortItemDownload);
-	ini.WriteInt("TableSortItemUpload", prefs->tableSortItemUpload);
-	ini.WriteInt("TableSortItemQueue", prefs->tableSortItemQueue);
-	ini.WriteInt("TableSortItemSearch", prefs->tableSortItemSearch);
-	ini.WriteInt("TableSortItemShared", prefs->tableSortItemShared);
-	ini.WriteInt("TableSortItemServer", prefs->tableSortItemServer);
-	ini.WriteBool("TableSortAscendingDownload", prefs->tableSortAscendingDownload);
-	ini.WriteBool("TableSortAscendingUpload", prefs->tableSortAscendingUpload);
-	ini.WriteBool("TableSortAscendingQueue", prefs->tableSortAscendingQueue);
-	ini.WriteBool("TableSortAscendingSearch", prefs->tableSortAscendingSearch);
-	ini.WriteBool("TableSortAscendingShared", prefs->tableSortAscendingShared);
-	ini.WriteBool("TableSortAscendingServer", prefs->tableSortAscendingServer);
-
-	CString buffer2;
-	for (int i=0;i<15;i++) {
-		buffer.Format("%llu",GetStatsColor(i));
-		buffer2.Format("StatColor%i",i);
-		ini.WriteString(buffer2,buffer);
-	}
-
-	buffer.Format("%llu",prefs->totalDownloadedBytes);
-	ini.WriteString("TotalDownloadedBytes",buffer ,"Statistics");
-
-	buffer.Format("%llu",prefs->totalUploadedBytes);
-	ini.WriteString("TotalUploadedBytes",buffer ,"Statistics");
-
-	CString catinif,ixStr;
-	catinif.Format("%sCategory.ini",appdir);
-	remove(catinif);
-
-	if (GetCatCount()>1) {
-		CIni catini( catinif, "Category" );
-		catini.WriteInt("Count",catMap.GetCount()-1,"General");
-		for (int ix=1;ix<catMap.GetCount();ix++){
-			ixStr.Format("Cat#%i",ix);
-			catini.WriteString("Title",catMap.GetAt(ix)->title,(char*)ixStr.GetData());
-			catini.WriteString("Incoming",catMap.GetAt(ix)->incomingpath,(char*)ixStr.GetData());
-			catini.WriteString("Comment",catMap.GetAt(ix)->comment,(char*)ixStr.GetData());
-			buffer.Format("%lu",catMap.GetAt(ix)->color);
-			catini.WriteString("Color",buffer,(char*)(ixStr.GetData()));
-		}
-	}
-#endif
+	// Madcat - Sources Dropping Tweaks
+	ini.WriteBool("NoNeededSources", prefs->DropNoNeededSources, "Razor_Preferences");
+	ini.WriteBool("SwapNoNeededSources", prefs->SwapNoNeededSources);
+	ini.WriteBool("FullQueueSources", prefs->DropFullQueueSources);
+	ini.WriteBool("HighQueueRankingSources", prefs->DropHighQueueRankingSources);
+	ini.WriteInt("HighQueueRanking", prefs->HighQueueRanking);
+	ini.WriteInt("AutoDropTimer", prefs->AutoDropTimer);
 }
 
 void CPreferences::SaveCats(){
@@ -912,17 +716,19 @@ void CPreferences::SaveCats(){
 	// Cats
 	CString catinif,ixStr,buffer;
 	catinif.Format("%sCategory.ini",appdir);
-	remove(catinif);
+	if(wxFileName::FileExists(catinif))
+		BackupFile(catinif, ".old");
 
-	if (GetCatCount()>1) {
+	if (GetCatCount()>0) {
 		CIni catini( catinif, "Category" );
+		printf("Opening %s\n",catinif.GetData());
 		catini.WriteInt("Count",catMap.GetCount()-1,"General");
 		for (int ix=1;ix<catMap.GetCount();ix++){
 			ixStr.Format("Cat#%i",ix);
 			catini.WriteString("Title",catMap.GetAt(ix)->title,(char*)ixStr.GetData());
 			catini.WriteString("Incoming",catMap.GetAt(ix)->incomingpath,(char*)ixStr.GetData());
 			catini.WriteString("Comment",catMap.GetAt(ix)->comment,(char*)ixStr.GetData());
-			buffer.Format("%lu",catMap.GetAt(ix)->color,(char*)ixStr.GetData());
+			buffer.Format("%lu",(unsigned long)catMap.GetAt(ix)->color);
 			catini.WriteString("Color",buffer,(char*)ixStr.GetData());
 			catini.WriteInt("Priority",catMap.GetAt(ix)->prio,(char*)ixStr.GetData());
 		}
@@ -966,17 +772,8 @@ void CPreferences::LoadPreferences(){
 
 	if ((strCurrVersion != strPrefsVersion) && wxFileName::FileExists(strFileName)){
 	  //CFile file;
-		//CFileFind findNewName;
-		CString strNewName;
-		strNewName.Format("%spreferences.ini.old", appdir);
-
-		if (wxFileName::FileExists(strNewName))
-		  //file.Remove(strNewName);
-		  remove(strNewName.GetData());
-
-		//file.Rename(strFileName, strNewName);
-		rename(strFileName.GetData(), strNewName.GetData());
-		strFileName = strNewName;
+	  	BackupFile(strFileName, ".old");
+		strFileName += ".old";
 	}
 	
 	CIni ini(strFileName, "eMule");
@@ -1051,10 +848,10 @@ void CPreferences::LoadPreferences(){
 		else 
 			prefs->depth3D = 5;
 
-    prefs->useDownloadNotifier=ini.GetBool("NotifyOnDownload",false);	// Added by enkeyDEV
-    prefs->useChatNotifier=ini.GetBool("NotifyOnChat",false);
-    prefs->useLogNotifier=ini.GetBool("NotifyOnLog",false);
-    prefs->useSoundInNotifier=ini.GetBool("NotifierUseSound",false);
+	prefs->useDownloadNotifier=ini.GetBool("NotifyOnDownload",false);	// Added by enkeyDEV
+	prefs->useChatNotifier=ini.GetBool("NotifyOnChat",false);
+	prefs->useLogNotifier=ini.GetBool("NotifyOnLog",false);
+	prefs->useSoundInNotifier=ini.GetBool("NotifierUseSound",false);
 	prefs->notifierPopsEveryChatMsg=ini.GetBool("NotifierPopEveryChatMessage",false);
 	prefs->notifierImportantError=ini.GetBool("NotifyOnImportantError",false);
 	prefs->notifierNewVersion=ini.GetBool("NotifierPopNewVersion",false);
@@ -1089,6 +886,7 @@ void CPreferences::LoadPreferences(){
 	prefs->m_bDAP=ini.GetBool("DAPPref",true);
 	prefs->m_bUAP=ini.GetBool("UAPPref",true);
 	prefs->indicateratings=ini.GetBool("IndicateRatings",true);
+	prefs->allcatType=ini.GetInt("AllcatType",0);
 	prefs->showAllNotCats=ini.GetBool("ShowAllNotCats",false);
 	prefs->watchclipboard=ini.GetBool("WatchClipboard4ED2kFilelinks",false);
 	prefs->log2disk=ini.GetBool("SaveLogToDisk",false);
@@ -1115,9 +913,6 @@ void CPreferences::LoadPreferences(){
 	sprintf(prefs->messageFilter,"%s",ini.GetString("MessageFilter","Your client has an infinite queue").GetData());
 	sprintf(prefs->commentFilter,"%s",ini.GetString("CommentFilter","http://").GetData());
 	
-	//if (prefs->maxGraphDownloadRate<prefs->maxdownload) prefs->maxdownload=UNLIMITED;
-	//if (prefs->maxGraphUploadRate<prefs->maxupload) prefs->maxupload=UNLIMITED;
-
 	ini.SerGet(true, prefs->downloadColumnWidths,
 		ELEMENT_COUNT(prefs->downloadColumnWidths), "DownloadColumnWidths", NULL, DEFAULT_COL_SIZE);
 	ini.SerGet(true, prefs->downloadColumnHidden,
@@ -1190,17 +985,22 @@ void CPreferences::LoadPreferences(){
 	prefs->proxy.type = ini.GetInt("ProxyType",PROXYTYPE_NOPROXY,"Proxy");
 
 	CString buffer2;
-	for (int i=0;i<15;i++) {
+	bool NoColor = true;
+	for (int i=0;i<13;i++) {
 		buffer2.Format("StatColor%i",i);
-		sprintf(buffer,ini.GetString(buffer2,"0"));
-		prefs->statcolors[i]=atoll(buffer);
-		if (prefs->statcolors[i]==0) {ResetStatsColor(i);}
+		sprintf(buffer,"%s", ini.GetString(buffer2,"0","eMule").c_str());
+		if ( (prefs->statcolors[i]=atoll(buffer)) ) NoColor = false;
+	}
+	if (NoColor) {
+		for ( int i=0; i<13; i++ ) {
+			ResetStatsColor(i);
+		}
 	}
 
-	sprintf(buffer,ini.GetString("TotalDownloadedBytes",0,"Statistics"));
+	sprintf(buffer,"%s",ini.GetString("TotalDownloadedBytes",0,"Statistics").c_str());
 	prefs->totalDownloadedBytes=atoll(buffer);
 
-	sprintf(buffer,ini.GetString("TotalUploadedBytes",0,"Statistics"));
+	sprintf(buffer,"%s", ini.GetString("TotalUploadedBytes",0,"Statistics").c_str());
 	prefs->totalUploadedBytes=atoll(buffer);
 	
 	prefs->desktopMode=ini.GetInt("DesktopMode",0);
@@ -1216,224 +1016,15 @@ void CPreferences::LoadPreferences(){
 
 	prefs->dontcompressavi=ini.GetBool("DontCompressAvi",false);
 
+	prefs->DropNoNeededSources=ini.GetBool("NoNeededSources", false,"Razor_Preferences");
+	prefs->SwapNoNeededSources=ini.GetBool("SwapNoNeededSources", false);
+	prefs->DropFullQueueSources=ini.GetBool("FullQueueSources", false);
+	prefs->DropHighQueueRankingSources=ini.GetBool("HighQueueRankingSources", false);
+	prefs->HighQueueRanking=ini.GetInt("HighQueueRanking", 1200);
+	prefs->AutoDropTimer=ini.GetInt("AutoDropTimer", 240);
+
 	LoadCats();
 
-	//SetLanguage();
-
-#if 0	
-	char buffer[200];
-
-	//--- Quick hack to add version tag to preferences.ini-file and solve the issue with the FlatStatusBar tag...
-	CString strFileName;
-	strFileName.Format("%spreferences.ini", appdir);
-	CIni* pIni = new CIni(strFileName, "eMule");
-
-	CString strCurrVersion, strPrefsVersion;
-
-	strCurrVersion = CURRENT_VERSION_LONG;
-	strPrefsVersion = CString(pIni->GetString("AppVersion").GetData());
-	delete pIni;
-
-	//CFileFind findFileName;
-
-	if ((strCurrVersion != strPrefsVersion) && wxFileName::FileExists(strFileName)){
-	  //CFile file;
-		//CFileFind findNewName;
-		CString strNewName;
-		strNewName.Format("%spreferences.ini.old", appdir);
-
-		if (wxFileName::FileExists(strNewName))
-		  //file.Remove(strNewName);
-		  remove(strNewName.GetData());
-
-		//file.Rename(strFileName, strNewName);
-		rename(strFileName.GetData(), strNewName.GetData());
-		strFileName = strNewName;
-	}
-
-	CIni ini(strFileName, "eMule");
-	//--- end Ozon :)
-
-	sprintf(buffer,"%s [http://www.xmule.org]", getenv("USER"));
-	sprintf(prefs->nick,"%s",ini.GetString("Nick",buffer ).GetData());
-	
-	sprintf(buffer,"%sIncoming",appdir);
-	sprintf(prefs->incomingdir,"%s",ini.GetString("IncomingDir",buffer ).GetData());
-
-	sprintf(buffer,"%sTemp",appdir);
-	sprintf(prefs->tempdir,"%s",ini.GetString("TempDir",buffer).GetData());
-
-	prefs->maxupload=ini.GetInt("MaxUpload",UNLIMITED);
-	prefs->maxdownload=ini.GetInt("MaxDownload",UNLIMITED);
-	prefs->maxconnections=ini.GetInt("MaxConnections",GetRecommendedMaxConnections());
-	prefs->deadserver=ini.GetInt("RemoveDeadServer",2);
-	prefs->port=ini.GetInt("Port",4662);
-	prefs->udpport=ini.GetInt("UDPPort",prefs->port+10);
-	prefs->maxsourceperfile=ini.GetInt("MaxSourcesPerFile",400 );
-	prefs->languageID=ini.GetWORD("Language",0);
-	prefs->m_iSeeShares=ini.GetInt("SeeShare",2);
-	prefs->m_iToolDelayTime=ini.GetInt("ToolTipDelay",1);
-	prefs->trafficOMeterInterval=ini.GetInt("StatGraphsInterval",3);
-	prefs->statsInterval=ini.GetInt("statsInterval",5);
-	prefs->maxGraphDownloadRate=ini.GetInt("DownloadCapacity",96);
-	prefs->maxGraphUploadRate=ini.GetInt("UploadCapacity",16);
-	prefs->deadserverretries=ini.GetInt("DeadServerRetry",1);
-	prefs->splitterbarPosition=ini.GetInt("SplitterbarPosition",75);
-	prefs->statsMax=ini.GetInt("VariousStatisticsMaxValue",100);
-	prefs->statsAverageMinutes=ini.GetInt("StatsAverageMinutes",5);
-	prefs->MaxConperFive=ini.GetInt("MaxConnectionsPerFiveSeconds",GetDefaultMaxConperFive());
-
-	prefs->reconnect=ini.GetBool("Reconnect",true);
-	prefs->scorsystem=ini.GetBool("Scoresystem",true);
-	prefs->ICH=ini.GetBool("ICH",true);
-	prefs->autoserverlist=ini.GetBool("Serverlist",false);
-	prefs->updatenotify=ini.GetBool("UpdateNotify",false);
-	prefs->mintotray=ini.GetBool("MinToTray",false);
-	prefs->addserversfromserver=ini.GetBool("AddServersFromServer",true);
-	prefs->addserversfromclient=ini.GetBool("AddServersFromClient",true);
-	prefs->splashscreen=ini.GetBool("Splashscreen",true);
-	prefs->bringtoforeground=ini.GetBool("BringToFront",true);
-	prefs->transferDoubleclick=ini.GetBool("TransferDoubleClick",true);
-	prefs->beepOnError=ini.GetBool("BeepOnError",true);
-	prefs->confirmExit=ini.GetBool("ConfirmExit",false);
-	prefs->filerBadIP=ini.GetBool("FilterBadIPs",true);
-	prefs->autoconnect=ini.GetBool("Autoconnect",false);
-	prefs->showRatesInTitle=ini.GetBool("ShowRatesOnTitle",false);
-
-	prefs->onlineSig=ini.GetBool("OnlineSignature",false);
-	prefs->startMinimized=ini.GetBool("StartupMinimized",false);
-	prefs->safeServerConnect =ini.GetBool("SafeServerConnect",false);
-
-	// Barry - New properties...
-	prefs->autoconnectstaticonly = ini.GetBool("AutoConnectStaticOnly",false); 
-	prefs->autotakeed2klinks = ini.GetBool("AutoTakeED2KLinks",true); 
-	prefs->addnewfilespaused = ini.GetBool("AddNewFilesPaused",false); 
-	prefs->depth3D = ini.GetInt("3DDepth", 0);
-
-	// my own
-	prefs->desktopMode=ini.GetInt("DesktopMode",0);
-
-	// as temporarial converter for previous versions
-	if (strPrefsVersion < "0.25a") // before 0.25a
-		if (ini.GetBool("FlatStatusBar",false))
-			prefs->depth3D = 0;
-		else 
-			prefs->depth3D = 5;
-
-	prefs->UAP = ini.GetBool("UAP", false) ;
-    prefs->useDownloadNotifier=ini.GetBool("NotifyOnDownload",false);	// Added by enkeyDEV
-    prefs->useChatNotifier=ini.GetBool("NotifyOnChat",false);
-    prefs->useLogNotifier=ini.GetBool("NotifyOnLog",false);
-    prefs->useSoundInNotifier=ini.GetBool("NotifierUseSound",false);
-	prefs->notifierPopsEveryChatMsg=ini.GetBool("NotifierPopEveryChatMessage",false);
-	prefs->notifierImportantError=ini.GetBool("NotifyOnImportantError",false);
-	prefs->notifierNewVersion=ini.GetBool("NotifierPopNewVersion",false);
-	sprintf(prefs->notifierSoundFilePath,"%s",ini.GetString("NotifierSoundPath","").GetData());
-
-	sprintf(prefs->m_sircserver,"%s",ini.GetString("DefaultIRCServer","irc.emule-project.net").GetData());
-	sprintf(prefs->m_sircnick,"%s",ini.GetString("IRCNick","eMule").GetData());
-	prefs->m_bircaddtimestamp=ini.GetBool("IRCAddTimestamp",true);
-	sprintf(prefs->m_sircchannamefilter,"%s",ini.GetString("IRCFilterName", "" ).GetData());
-	prefs->m_bircusechanfilter=ini.GetBool("IRCUseFilter", false);
-	prefs->m_iircchanneluserfilter=ini.GetInt("IRCFilterUser", 0);
-	sprintf(prefs->m_sircperformstring,"%s",ini.GetString("IRCPerformString", "/join #emule" ).GetData());
-	prefs->m_bircuseperform=ini.GetBool("IRCUsePerform", false);
-	prefs->m_birclistonconnect=ini.GetBool("IRCListOnConnect", true);
-	prefs->m_bircacceptlinks=ini.GetBool("IRCAcceptLinks", false);
-	prefs->m_bircignoreinfomessage=ini.GetBool("IRCIgnoreInfoMessage", false);
-	prefs->m_bircignoreemuleprotoinfomessage=ini.GetBool("IRCIgnoreEmuleProtoInfoMessage", true);
-	prefs->smartidcheck=ini.GetBool("SmartIdCheck",true);
-	prefs->m_bVerbose=ini.GetBool("Verbose",false);
-	prefs->m_bpreviewprio=ini.GetBool("PreviewPrio",false);
-	prefs->m_bupdatequeuelist=ini.GetBool("UpdateQueueListPref",false);
-	prefs->m_bmanualhighprio=ini.GetBool("ManualHighPrio",false);
-	prefs->m_btransferfullchunks=ini.GetBool("FullChunkTransfers",true);
-	prefs->m_bstartnextfile=ini.GetBool("StartNextFile",false);
-	prefs->m_bshowoverhead=ini.GetBool("ShowOverhead",false);
-	prefs->moviePreviewBackup=ini.GetBool("VideoPreviewBackupped",true);
-	prefs->m_iFileBufferSize=ini.GetInt("FileBufferSizePref",16);
-	prefs->m_iQueueSize=ini.GetInt("QueueSizePref",50);
-	prefs->versioncheckdays=ini.GetInt("Check4NewVersionDelay",5);
-
-	prefs->versioncheckLastAutomatic=ini.GetInt("VersionCheckLastAutomatic",0);
-
-	sprintf(prefs->TxtEditor,"%s",ini.GetString("TxtEditor","notepad.exe").GetData());
-	sprintf(prefs->VideoPlayer,"%s",ini.GetString("VideoPlayer","").GetData());
-
-	sprintf(prefs->messageFilter,"%s",ini.GetString("MessageFilter","Your client has an infinite queue").GetData());
-	
-	//if (prefs->maxGraphDownloadRate<prefs->maxdownload) prefs->maxdownload=UNLIMITED;
-	//if (prefs->maxGraphUploadRate<prefs->maxupload) prefs->maxupload=UNLIMITED;
-
-	ini.SerGet(true, prefs->downloadColumnWidths,
-		ELEMENT_COUNT(prefs->downloadColumnWidths), "DownloadColumnWidths", NULL, DEFAULT_COL_SIZE);
-	ini.SerGet(true, prefs->downloadColumnHidden,
-		ELEMENT_COUNT(prefs->downloadColumnHidden), "DownloadColumnHidden");
-	ini.SerGet(true, prefs->downloadColumnOrder,
-		ELEMENT_COUNT(prefs->downloadColumnOrder), "DownloadColumnOrder");
-	ini.SerGet(true, prefs->uploadColumnWidths,
-		ELEMENT_COUNT(prefs->uploadColumnWidths), "UploadColumnWidths", NULL, DEFAULT_COL_SIZE);
-	ini.SerGet(true, prefs->uploadColumnHidden,
-		ELEMENT_COUNT(prefs->uploadColumnHidden), "UploadColumnHidden");
-	ini.SerGet(true, prefs->uploadColumnOrder,
-		ELEMENT_COUNT(prefs->uploadColumnOrder), "UploadColumnOrder");
-	ini.SerGet(true, prefs->queueColumnWidths,
-		ELEMENT_COUNT(prefs->queueColumnWidths), "QueueColumnWidths", NULL, DEFAULT_COL_SIZE);
-	ini.SerGet(true, prefs->queueColumnHidden,
-		ELEMENT_COUNT(prefs->queueColumnHidden), "QueueColumnHidden");
-	ini.SerGet(true, prefs->queueColumnOrder,
-		ELEMENT_COUNT(prefs->queueColumnOrder), "QueueColumnOrder");
-	ini.SerGet(true, prefs->searchColumnWidths,
-		ELEMENT_COUNT(prefs->searchColumnWidths), "SearchColumnWidths", NULL, DEFAULT_COL_SIZE);
-	ini.SerGet(true, prefs->searchColumnHidden,
-		ELEMENT_COUNT(prefs->searchColumnHidden), "SearchColumnHidden");
-	ini.SerGet(true, prefs->searchColumnOrder,
-		ELEMENT_COUNT(prefs->searchColumnOrder), "SearchColumnOrder");
-	ini.SerGet(true, prefs->sharedColumnWidths,
-		ELEMENT_COUNT(prefs->sharedColumnWidths), "SharedColumnWidths", NULL, DEFAULT_COL_SIZE);
-	ini.SerGet(true, prefs->sharedColumnHidden,
-		ELEMENT_COUNT(prefs->sharedColumnHidden), "SharedColumnHidden");
-	ini.SerGet(true, prefs->sharedColumnOrder,
-		ELEMENT_COUNT(prefs->sharedColumnOrder), "SharedColumnOrder");
-	ini.SerGet(true, prefs->serverColumnWidths,
-		ELEMENT_COUNT(prefs->serverColumnWidths), "ServerColumnWidths", NULL, DEFAULT_COL_SIZE);
-	ini.SerGet(true, prefs->serverColumnHidden,
-		ELEMENT_COUNT(prefs->serverColumnHidden), "ServerColumnHidden");
-	ini.SerGet(true, prefs->serverColumnOrder,
-		ELEMENT_COUNT(prefs->serverColumnOrder), "ServerColumnOrder");
-
-	// Barry - Provide a mechanism for all tables to store/retrieve sort order
-	prefs->tableSortItemDownload = ini.GetInt("TableSortItemDownload", 0);
-	prefs->tableSortItemUpload = ini.GetInt("TableSortItemUpload", 0);
-	prefs->tableSortItemQueue = ini.GetInt("TableSortItemQueue", 0);
-	prefs->tableSortItemSearch = ini.GetInt("TableSortItemSearch", 0);
-	prefs->tableSortItemShared = ini.GetInt("TableSortItemShared", 0);
-	prefs->tableSortItemServer = ini.GetInt("TableSortItemServer", 0);
-	prefs->tableSortAscendingDownload = ini.GetBool("TableSortAscendingDownload", true);
-	prefs->tableSortAscendingUpload = ini.GetBool("TableSortAscendingUpload", true);
-	prefs->tableSortAscendingQueue = ini.GetBool("TableSortAscendingQueue", true);
-	prefs->tableSortAscendingSearch = ini.GetBool("TableSortAscendingSearch", true);
-	prefs->tableSortAscendingShared = ini.GetBool("TableSortAscendingShared", true);
-	prefs->tableSortAscendingServer = ini.GetBool("TableSortAscendingServer", true);
-
-	if (prefs->statsAverageMinutes<1) prefs->statsAverageMinutes=5;
-
-	CString buffer2;
-	for (int i=0;i<15;i++) {
-		buffer2.Format("StatColor%i",i);
-		sprintf(buffer,ini.GetString(buffer2,"0"));
-		prefs->statcolors[i]=atoll(buffer);
-		if (prefs->statcolors[i]==0) {ResetStatsColor(i);}
-	}
-
-	sprintf(buffer,ini.GetString("TotalDownloadedBytes",0,"Statistics"));
-	prefs->totalDownloadedBytes=atoll(buffer);
-
-	sprintf(buffer,ini.GetString("TotalUploadedBytes",0,"Statistics"));
-	prefs->totalUploadedBytes=atoll(buffer);
-
-	//SetLanguage();
-#endif
 }
 
 void CPreferences::LoadCats() {
@@ -1452,7 +1043,9 @@ void CPreferences::LoadCats() {
 	AddCat(newcat);
 
 	//if (!PathFileExists(catinif)) return;
-	if(!wxFileName::FileExists(catinif)) return;
+	// surprise, surprise it won't exist
+	// the system is now stupid enough to put everything in .eMule :(
+	// if(!wxFileName::FileExists(catinif)) return;
 
 	CIni catini( catinif, "Category" );
 	int max=catini.GetInt("Count",0,"General");
@@ -1461,12 +1054,12 @@ void CPreferences::LoadCats() {
 		ixStr.Format("Cat#%i",ix);
 
 		Category_Struct* newcat=new Category_Struct;
-		sprintf(newcat->title,catini.GetString("Title","",(char*)ixStr.GetData()));
-		sprintf(newcat->incomingpath,catini.GetString("Incoming","",(char*)ixStr.GetData()));
+		sprintf(newcat->title,"%s",catini.GetString("Title","",(char*)ixStr.GetData()).c_str());
+		sprintf(newcat->incomingpath,"%s",catini.GetString("Incoming","",(char*)ixStr.GetData()).c_str());
 		MakeFoldername(newcat->incomingpath);
-		sprintf(newcat->comment,catini.GetString("Comment","",(char*)ixStr.GetData()));
+		sprintf(newcat->comment,"%s",catini.GetString("Comment","",(char*)ixStr.GetData()).c_str());
 		newcat->prio =catini.GetInt("Priority",0,(char*)ixStr.GetData());
-		sprintf(buffer,catini.GetString("Color","0",(char*)ixStr.GetData()));
+		sprintf(buffer,"%s",catini.GetString("Color","0",(char*)ixStr.GetData()).c_str());
 		newcat->color=atoll(buffer);
 
 		AddCat(newcat);
@@ -1485,20 +1078,6 @@ WORD CPreferences::GetWindowsVersion(){
 }
 
 uint16 CPreferences::GetDefaultMaxConperFive(){
-#if 0
-	switch (GetWindowsVersion()){
-		case _WINVER_98_:
-			return 5;
-		case _WINVER_95_:	
-		case _WINVER_ME_:
-			return MAXCON5WIN9X;
-		case _WINVER_2K_:
-		case _WINVER_XP_:
-			return MAXCONPER5SEC;
-		default:
-			return MAXCONPER5SEC;
-	}
-#endif
 	return MAXCONPER5SEC;
 }
 
