@@ -63,18 +63,13 @@ void CServerList::AutoUpdate(){
 	}
 	bool bDownloaded=false;
 	CString servermetdownload;
-	CString servermetbackup;
+//	CString servermetbackup;
 	CString servermet;
 	CString strURLToDownload; 
 	servermetdownload.Format("%sserver_met.download",app_prefs->GetAppDir());
-	servermetbackup.Format("%sserver_met.old",app_prefs->GetAppDir());
 	servermet.Format("%sserver.met",app_prefs->GetAppDir());
-	remove(servermetbackup.GetData());
-	//printf("**removed %s\n",servermetbackup.GetData());
-	remove(servermetdownload.GetData());
-	//printf("**and removed %s\n",servermetdownload.GetData());
-	rename(servermet.GetData(),servermetbackup.GetData());
-	//printf("**renamed %s->%s\n",servermet.GetData(),servermetbackup.GetData());
+	BackupFile(servermet, ".old");
+	wxRemoveFile(servermetdownload);
 	POSITION Pos = app_prefs->adresses_list.GetHeadPosition(); 
 	while ((!bDownloaded) && (Pos != NULL)){
 		CHTTPDownloadDlg* dlgDownload;
@@ -91,16 +86,12 @@ void CServerList::AutoUpdate(){
 		delete dlgDownload;
 	}
 	if (bDownloaded){
-		rename(servermet.GetData(), servermetdownload.GetData());
-		//printf("***after renamed %s->%s\n",servermet.GetData(),servermetdownload.GetData());
-		rename(servermetbackup.GetData(), servermet.GetData());
-		//printf("***after renamed %s->%s\n",servermetbackup.GetData(),servermet.GetData());
+		wxRenameFile(servermet, servermetdownload);
+		wxRenameFile(servermet+".old",servermet);
 	}
 	else{
-		remove(servermet.GetData());
-		//printf("**after2: removed %s\n",servermet.GetData());
-		rename(servermetbackup.GetData(),servermet.GetData());
-		//printf("**after2: renamed %s\n",servermetbackup.GetData(),servermet.GetData());
+		wxRemoveFile(servermet);
+		wxRenameFile(servermet+".old",servermet);
 	}
 }
 
@@ -132,7 +123,7 @@ bool CServerList::AddServermetToList(CString strFile, bool merge){
       this->RemoveAllServers();
     }
   CSafeFile servermet;
-  /*try*/{
+//  /*try*/{
     if(!wxFileExists(strFile)) {
       theApp.xmuledlg->AddLogLine(false,_("Failed to load server.met!"));
       return false;
@@ -142,26 +133,31 @@ bool CServerList::AddServermetToList(CString strFile, bool merge){
       theApp.xmuledlg->AddLogLine(false,_("Failed to load server.met!"));
       return false;
     }
-    servermet.Read(&version,1);
-    if (version != 0xE0 && version != MET_HEADER){
+    if ( (1 != servermet.Read(&version,1)) ||
+         (version != 0xE0 && version != MET_HEADER)){
       servermet.Close();
       theApp.xmuledlg->AddLogLine(false,GetResString(IDS_ERR_BADSERVERMETVERSION),version);
       return false;
     }
+
+    try
+    {
     uint32 fservercount;
-    servermet.Read(&fservercount,4);
+    	if ( 4 != servermet.Read(&fservercount,4) )
+    		throw CInvalidPacket();
     
     ServerMet_Struct sbuffer;
     uint32 iAddCount = 0;
 
     theApp.xmuledlg->serverwnd->serverlistctrl->Freeze();
 
-    for (uint32 j = 0;j != fservercount;j++){
+    	for (uint32 j = 0;j < fservercount;j++){
       // get server
-      servermet.Read(&sbuffer,sizeof(ServerMet_Struct));
+      		if ( sizeof(ServerMet_Struct) != servermet.Read(&sbuffer,sizeof(ServerMet_Struct)) )
+      			throw CInvalidPacket();
       CServer* newserver = new CServer(&sbuffer);
       //add tags
-      for (uint32 i=0;i != sbuffer.tagcount;i++)
+      		for (uint32 i=0;i < sbuffer.tagcount;i++)
 	newserver->AddTagFromFile(&servermet);
       // set listname for server
       if (!newserver->GetListName()){
@@ -191,8 +187,14 @@ bool CServerList::AddServermetToList(CString strFile, bool merge){
       theApp.xmuledlg->AddLogLine(true,GetResString(IDS_SERVERSFOUND),fservercount);
     else
       theApp.xmuledlg->AddLogLine(true,GetResString(IDS_SERVERSADDED), iAddCount, fservercount-iAddCount);
+   }
+   catch ( CInvalidPacket )
+   {
+   	theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_BADSERVERLIST));
     servermet.Close();
+   	return false;
   }
+   servermet.Close();
 #if 0
   catch(CFileException* error){
     if (error->m_cause == CFileException::endOfFile)
@@ -699,9 +701,9 @@ bool CServerList::SaveServermetToFile(){
 	char* oldservermet = new char[strlen(app_prefs->GetAppDir())+20];
 	sprintf(curservermet,"%sserver.met",app_prefs->GetAppDir());
 	sprintf(oldservermet,"%sserver_met.old",app_prefs->GetAppDir());
-	remove(oldservermet);
-	rename(curservermet,oldservermet);
-	rename(newservermet,curservermet);
+	wxRemoveFile(oldservermet);
+	wxRenameFile(curservermet,oldservermet);
+	wxRenameFile(newservermet,curservermet);
 	delete[] oldservermet;
 	delete[] curservermet;
 	}
