@@ -177,7 +177,7 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 				break;
 			}
 			case OP_IDCHANGE:{
-				if (size != sizeof(LoginAnswer_Struct)){
+				if (size < sizeof(LoginAnswer_Struct)){
 					throw GetResString(IDS_ERR_BADSERVERREPLY);
 				}
 				LoginAnswer_Struct* la = (LoginAnswer_Struct*) packet;
@@ -210,6 +210,7 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 						}
 					}
 				}
+				serverconnect->clientid = la->clientid;
 				if (connectionstate != CS_CONNECTED) {
 					SetConnectionState(CS_CONNECTED);
 					theApp.OnlineSig();       // Added By Bouc7 
@@ -230,6 +231,8 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 			}
 			case OP_SEARCHRESULT:{
 				theApp.xmuledlg->searchwnd->LocalSearchEnd(theApp.searchlist->ProcessSearchanswer(packet,size));
+				theApp.downloadqueue->AddDownDataOverheadServer(size);
+ 				CServer* cur_srv = (serverconnect) ? serverconnect->GetCurrentServer() : NULL;
 				break;
 			}
 			case OP_FOUNDSOURCES:{
@@ -361,7 +364,7 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 }
 
 void CServerSocket::ConnectToServer(CServer* server){
-  cur_server = new CServer(server);
+	cur_server = new CServer(server);
 	theApp.xmuledlg->AddLogLine(false,GetResString(IDS_CONNECTINGTO),cur_server->GetListName(),cur_server->GetFullIP(),cur_server->GetPort());
 	SetConnectionState(CS_CONNECTING);
 
@@ -388,8 +391,20 @@ void CServerSocket::OnError(int nErrorCode){
 #endif
 }
 
-void CServerSocket::PacketReceived(Packet* packet){
-  ProcessPacket(packet->pBuffer,packet->size,packet->opcode);
+void CServerSocket::PacketReceived(Packet* packet) {
+	if (packet->prot == OP_PACKEDPROT) {
+			uint32 uComprSize = packet->size;
+			if (!packet->UnPackPacket(250000)) {
+				theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
+				return;
+			}
+			packet->prot = OP_EDONKEYPROT;
+		} else if (packet->prot == OP_EDONKEYPROT) {
+			ProcessPacket(packet->pBuffer,packet->size,packet->opcode);
+		} else {
+			theApp.xmuledlg->AddDebugLogLine(false,_T("Received server TCP packet with unknown protocol: protocol=0x%02x  opcode=0x%02x  size=%u"), packet ? packet->prot : 0, packet ? packet->opcode : 0, packet ? packet->size : 0);
+			theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
+		}
 }
 
 void CServerSocket::OnClose(int nErrorCode){
