@@ -32,6 +32,7 @@
 #include "PartFile.h"
 #include "MapKey.h"
 #include <wx/thread.h>
+#include "mfc.h"
 
 /*
 struct UnknownFile_Struct{
@@ -107,6 +108,9 @@ public:
 	uint16	GetCount()	{return m_Files_map.size(); }
 	void	UpdateItem(CKnownFile* toupdate);
 	void	AddFilesFromDirectory(char* directory);
+	void	GetSharedFilesByDirectory(const char *directory,
+                            CTypedPtrList<CPtrList, CKnownFile*>& list);
+
 private:
 	void	FindSharedFiles();
 
