@@ -46,7 +46,7 @@ CSharedFilesCtrl::~CSharedFilesCtrl(){
 }
 
 CSharedFilesCtrl::CSharedFilesCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags)
-  : CMuleListCtrl(parent,id,pos,siz,flags)
+  : CMuleListCtrl(parent,id,pos,siz,flags|wxLC_OWNERDRAW)
 {
    sflist = 0;                // i_a 
    memset(&sortstat, 0, sizeof(sortstat));  // i_a 
@@ -77,6 +77,7 @@ void CSharedFilesCtrl::Init(){
 	InsertColumn(6,GetResString(IDS_SF_REQUESTS),LVCFMT_LEFT,100);
 	InsertColumn(7,GetResString(IDS_SF_ACCEPTS),LVCFMT_LEFT,100);
 	InsertColumn(8,GetResString(IDS_SF_TRANSFERRED),LVCFMT_LEFT,120);
+	InsertColumn(9,GetResString(IDS_UPSTATUS),LVCFMT_LEFT,120);
 
 #if 0
 	SetExtendedStyle(LVS_EX_FULLROWSELECT);
@@ -241,12 +242,13 @@ void CSharedFilesCtrl::RemoveFile(CKnownFile *toRemove) {
 
 void CSharedFilesCtrl::UpdateFile(CKnownFile* file,uint32 itemnr){
 	CString buffer;
+	SetItemData(itemnr,(long)file);
 	SetItem(itemnr,1,CastItoXBytes(file->GetFileSize()));
 	SetItem(itemnr,2,GetFiletypeByName(file->GetFileName()));  // added by InterCeptor (show filetype) 11.11.02
 	//UAP
-	if ((file->IsAutoPrioritized())&&(theApp.glob_prefs->GetNewAutoUp()))
+	if ((file->IsAutoUpPriority())&&(theApp.glob_prefs->GetNewAutoUp()))
 	{
-		switch (file->GetPriority()) {
+		switch (file->GetUpPriority()) {
 			case PR_NORMAL : {
 				SetItem(itemnr,3,GetResString(IDS_PRIOAUTONORMAL ));
 				break; }
@@ -259,7 +261,7 @@ void CSharedFilesCtrl::UpdateFile(CKnownFile* file,uint32 itemnr){
 		}
 	} else {
 	//endUAP
-		switch (file->GetPriority()) {
+		switch (file->GetUpPriority()) {
 			case PR_VERYLOW : {
 				SetItem(itemnr,3,GetResString(IDS_PRIOVERYLOW ));
 				break; }
@@ -302,15 +304,15 @@ void CSharedFilesCtrl::UpdateFile(CKnownFile* file,uint32 itemnr){
   CastItoXBytes(file->GetFileSize(),buffer);
   SetItem(itemnr,1,buffer);
   SetItem(itemnr,2,GetFiletypeByName(file->GetFileName()));  // added by InterCeptor (show filetype) 11.11.02 
-  if (file->GetPriority() == PR_VERYLOW)
+  if (file->GetUpPriority() == PR_VERYLOW)
     SetItem(itemnr,3,GetResString(IDS_PRIOVERYLOW ));
-  else if (file->GetPriority() == PR_LOW)
+  else if (file->GetUpPriority() == PR_LOW)
     SetItem(itemnr,3,GetResString(IDS_PRIOLOW ));
-  else if (file->GetPriority() == PR_NORMAL)
+  else if (file->GetUpPriority() == PR_NORMAL)
     SetItem(itemnr,3,GetResString(IDS_PRIONORMAL ));
-  else if (file->GetPriority() == PR_HIGH)
+  else if (file->GetUpPriority() == PR_HIGH)
     SetItem(itemnr,3,GetResString(IDS_PRIOHIGH ));
-  else if (file->GetPriority() == PR_VERYHIGH)
+  else if (file->GetUpPriority() == PR_VERYHIGH)
     SetItem(itemnr,3,GetResString(IDS_PRIORELEASE ));
   
   /*if (file->GetPermissions() == PERM_NOONE)
@@ -463,25 +465,30 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent& evt)
 	    file = (CKnownFile*)this->GetItemData(iSel);
 	    switch (event.GetId()) {
 	    case MP_PRIOVERYLOW:
-	      {	file->SetPriority(PR_VERYLOW);SetItem(iSel,3,GetResString(IDS_PRIOVERYLOW ));break;	}
+	      {	file->SetAutoUpPriority(false);
+	      file->SetUpPriority(PR_VERYLOW);SetItem(iSel,3,GetResString(IDS_PRIOVERYLOW ));break;	}
 	    case MP_PRIOLOW:
-	      {	file->SetPriority(PR_LOW);SetItem(iSel,3,GetResString(IDS_PRIOLOW ));break;	}
+	      {	file->SetAutoUpPriority(false);
+	      	file->SetUpPriority(PR_LOW);SetItem(iSel,3,GetResString(IDS_PRIOLOW ));break;	}
 	    case MP_PRIONORMAL:
-	      {	file->SetPriority(PR_NORMAL);SetItem(iSel,3,GetResString(IDS_PRIONORMAL ));break;	}
+	      {	file->SetAutoUpPriority(false);
+	      	file->SetUpPriority(PR_NORMAL);SetItem(iSel,3,GetResString(IDS_PRIONORMAL ));break;	}
 	    case MP_PRIOHIGH:
-	      {	file->SetPriority(PR_HIGH);SetItem(iSel,3,GetResString(IDS_PRIOHIGH ));break;	}
+	      {	file->SetAutoUpPriority(false);
+	      	file->SetUpPriority(PR_HIGH);SetItem(iSel,3,GetResString(IDS_PRIOHIGH ));break;	}
 	    case MP_PRIOVERYHIGH:
-	      {	file->SetPriority(PR_VERYHIGH);SetItem(iSel,3,GetResString(IDS_PRIORELEASE ));break;	}
+	      {	file->SetAutoUpPriority(false);
+	      	file->SetUpPriority(PR_VERYHIGH);SetItem(iSel,3,GetResString(IDS_PRIORELEASE ));break;	}
 	    case MP_PRIOAUTO:
 	      {
 		if (file->IsPartFile()) {
-		  file->SetAutoPriority(true) ;
-		  file->UpdateUploadAutoPriority() ;
-		  if (file->GetPriority() == PR_VERYHIGH)
+		  file->SetAutoUpPriority(true) ;
+		  file->UpdateAutoUpPriority() ;
+		  if (file->GetUpPriority() == PR_VERYHIGH)
 		    SetItem(iSel,3,GetResString(IDS_PRIOAUTORELEASE));
-		  else if (file->GetPriority() == PR_HIGH)
+		  else if (file->GetUpPriority() == PR_HIGH)
 		    SetItem(iSel,3,GetResString(IDS_PRIOAUTOHIGH));
-		  else if (file->GetPriority() == PR_NORMAL)
+		  else if (file->GetUpPriority() == PR_NORMAL)
 		    SetItem(iSel,3,GetResString(IDS_PRIOAUTONORMAL));
 		}
 		else no_partfile_selected = true;
@@ -577,19 +584,19 @@ int CSharedFilesCtrl::SortProc(long lParam1, long lParam2, long lParamSort){
 			return strcasecmp( GetFiletypeByName(item2->GetFileName()),GetFiletypeByName( item1->GetFileName()) );
 
 		case 3: //prio asc
-			if(item1->GetPriority() == PR_VERYLOW )
+			if(item1->GetUpPriority() == PR_VERYLOW )
 				return 1;
-			else if (item2->GetPriority() == PR_VERYLOW)
+			else if (item2->GetUpPriority() == PR_VERYLOW)
 				return 0;
 			else
-				return item2->GetPriority()-item1->GetPriority();
+				return item2->GetUpPriority()-item1->GetUpPriority();
 		case 23: //prio desc
-			if(item1->GetPriority() == PR_VERYLOW )
+			if(item1->GetUpPriority() == PR_VERYLOW )
 				return 0;
-			else if (item2->GetPriority() == PR_VERYLOW)
+			else if (item2->GetUpPriority() == PR_VERYLOW)
 				return 1;
 			else
-				return item1->GetPriority()-item2->GetPriority();
+				return item1->GetUpPriority()-item2->GetUpPriority();
 
 		case 4: //permission asc
 			return item2->GetPermissions()-item1->GetPermissions();
@@ -654,3 +661,73 @@ void CSharedFilesCtrl::ShowFilesCount() {
 	wxString fmtstr = wxString::Format(_("Shared Files (%i)"), GetItemCount());
 	wxStaticCast(FindWindowByName(wxT("sharedFilesLabel")),wxStaticText)->SetLabel(fmtstr); 
 }
+
+void CSharedFilesCtrl::OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRect& rectHL,bool highlighted)
+{
+	CKnownFile *file = (CKnownFile*)GetItemData(item);
+	assert(file != NULL);
+
+	if ( highlighted ) {
+		wxColour newcol;
+		wxBrush hilBrush;
+
+		if (GetFocus()) {
+			wxColour col=wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHT);
+			newcol=wxColour(G_BLEND(col.Red(),125),
+				   G_BLEND(col.Green(),125),
+				   G_BLEND(col.Blue(),125));
+			hilBrush = wxBrush(newcol,wxSOLID);
+			dc->SetBackground(hilBrush);
+			dc->SetTextForeground(wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHTTEXT));
+		} else {
+			wxColour col=wxSystemSettings::GetColour(wxSYS_COLOUR_BTNSHADOW);
+  			newcol=wxColour(G_BLEND(col.Red(),125),
+				  G_BLEND(col.Green(),125),
+				  G_BLEND(col.Blue(),125));
+ 			hilBrush=wxBrush(newcol,wxSOLID);
+			dc->SetBackground(hilBrush);
+			dc->SetTextForeground(wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHTTEXT));
+		}
+
+		newcol = wxColour(((int)newcol.Red()*65)/100,
+			          ((int)newcol.Green()*65)/100,
+			          ((int)newcol.Blue()*65)/100);
+		dc->SetPen(wxPen(newcol,1,wxSOLID));
+	} else {
+		dc->SetBackground(*(wxTheBrushList->FindOrCreateBrush(wxSystemSettings::GetColour(wxSYS_COLOUR_LISTBOX),wxSOLID)));
+		dc->SetTextForeground(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
+		dc->SetPen(*wxTRANSPARENT_PEN);
+	}
+	dc->SetBrush(dc->GetBackground());
+	dc->DrawRectangle(rectHL);
+	dc->SetPen(*wxTRANSPARENT_PEN);
+
+	wxRect columnRect = rect;
+#define SPARE_PIXELS_HORZ	4
+#define SPARE_PIXELS_VERT_TEXT	3
+	columnRect.SetLeft(columnRect.GetLeft()+SPARE_PIXELS_HORZ);
+	columnRect.SetWidth(columnRect.GetWidth()-2*SPARE_PIXELS_HORZ);
+	for ( int iColumn = 0; iColumn < GetColumnCount(); iColumn++ )
+	{
+		wxListItem columnItem;
+		GetColumn(iColumn, columnItem);
+		int width = columnItem.GetWidth();
+		columnRect.SetWidth(width-2*SPARE_PIXELS_HORZ);
+		wxDCClipper clipper(*dc, columnRect);
+		switch ( iColumn )
+		{
+		case 9:
+			file->DrawShareStatusBar(dc, columnRect, false, theApp.glob_prefs->UseFlatBar());
+			break;
+		default:
+			columnItem.m_col = iColumn;
+			columnItem.m_itemId = item;
+			GetItem(columnItem);
+			dc->DrawText(columnItem.m_text, columnRect.GetLeft(), columnRect.GetTop()+SPARE_PIXELS_VERT_TEXT);
+			break;
+
+		}
+
+		columnRect.SetLeft(columnRect.GetLeft()+width);
+	}
+}
