@@ -95,10 +95,12 @@ void CStatisticsDlg::Init()
   m_Statistics->SetBackgroundColor(RGB(0, 0, 64)) ;
   m_Statistics->SetGridColor(RGB(192, 192, 255)) ;
   m_Statistics->SetRanges(0, theApp.glob_prefs->GetStatsMax()) ;
-  m_Statistics->autofitYscale=true;
+// This does not work!  
+//  m_Statistics->autofitYscale=true;
+  m_Statistics->autofitYscale=false;
   
-  m_Statistics->SetPlotColor( RGB(150, 150, 255),0) ;
-  m_Statistics->SetPlotColor( RGB(192,   0, 192),1) ;
+  m_Statistics->SetPlotColor( RGB(192,   0, 192),0) ;
+  m_Statistics->SetPlotColor( RGB(150, 150, 255),1) ;
   m_Statistics->SetPlotColor( RGB(255, 192, 255),2) ;
   m_Statistics->SetPlotColor( RGB(255, 255, 128),3) ;
   m_Statistics->SetYUnits("") ;
@@ -220,8 +222,8 @@ void CStatisticsDlg::RepaintMeters() {
 
 	m_Statistics->SetBackgroundColor(theApp.glob_prefs->GetStatsColor(0)) ;
 	m_Statistics->SetGridColor(theApp.glob_prefs->GetStatsColor(1)) ;
-	m_Statistics->SetPlotColor( theApp.glob_prefs->GetStatsColor(8),0) ;
-	m_Statistics->SetPlotColor( theApp.glob_prefs->GetStatsColor(10),1) ;
+	m_Statistics->SetPlotColor( theApp.glob_prefs->GetStatsColor(10),0) ;
+	m_Statistics->SetPlotColor( theApp.glob_prefs->GetStatsColor(8),1) ;
 	//m_Statistics.SetPlotColor( theApp.glob_prefs->GetStatsColor(10),2) ;
 	m_Statistics->SetPlotColor( theApp.glob_prefs->GetStatsColor(9),3) ;
 
@@ -234,8 +236,8 @@ void CStatisticsDlg::RepaintMeters() {
 	SetupLegend( IDC_C1,   2 ,2 );
 	
 
-	SetupLegend( IDC_S0, 0 ,3);
-	SetupLegend( IDC_S1, 1 ,3);
+	SetupLegend( IDC_S0, 1 ,3);
+	SetupLegend( IDC_S1, 0 ,3);
 	//SetupLegend( IDC_S2, 2 ,3);
 	SetupLegend( IDC_S3, 3 ,3);
 }
@@ -275,6 +277,31 @@ void CStatisticsDlg::SetupLegend( int ResIdx, int ElmtIdx, int legendNr){
 
 
 void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate) {
+	// Update scaling of the active connections graph
+	static uint32 savedMaxConns;
+	if ( savedMaxConns != theApp.glob_prefs->GetMaxConnections() )
+	{
+		savedMaxConns = theApp.glob_prefs->GetMaxConnections();
+
+		unsigned x = 1, by = 1;
+		unsigned max = theApp.glob_prefs->GetStatsMax();
+		if ( savedMaxConns < max ) {
+			x = max / savedMaxConns;
+			if ( max < (x*savedMaxConns) )
+				x--;
+			max = max / x;
+		} else {
+			by = (savedMaxConns+max-1) / max;
+			if ( (by*max) < savedMaxConns )
+				by++;
+			max = max * by;
+		}
+
+		wxString txt = wxString::Format(GetResString(IDS_ST_ACTIVEC), x, by);
+		wxStaticCast(wxWindow::FindWindowById(ID_ACTIVEC),wxStaticText)->SetLabel(txt);
+  		m_Statistics->SetRange(0, max, 1) ;
+	}
+
 	double m_dPlotDataUp[ 3 ];
 	double m_dPlotDataDown[ 3 ];
 	int myStats[6];
@@ -307,8 +334,8 @@ void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate) {
 	activeconnections = theApp.listensocket->GetOpenSockets();
 
 	theApp.downloadqueue->GetDownloadStats(myStats);
-	m_dPlotDataMore[0]=(activeconnections/3);//myStats[0];
-	m_dPlotDataMore[1]=theApp.uploadqueue->GetUploadQueueLength();
+	m_dPlotDataMore[0]=theApp.uploadqueue->GetUploadQueueLength();
+	m_dPlotDataMore[1]=activeconnections;//myStats[0];
 	m_dPlotDataMore[2]=0;//theApp.uploadqueue->GetWaitingUserCount();
 	m_dPlotDataMore[3]=myStats[1];
 
@@ -810,10 +837,10 @@ void CStatisticsDlg::ExportHTMLEvent(wxEvent& evt) {
 
         item=stattree->GetRootItem();
         text=stattree->GetItemText(item);
-        while (item!=NULL)
+        while (item)
         {
                 item=stattree->GetNextVisible(item);
-                if (item==NULL) break;
+                if (!item) break;
  
                 stattree->Expand(item);//,TVE_EXPAND);
  
