@@ -23,6 +23,7 @@
 #include "wintypes.h"
 #include "xmule.h"
 #include "TransferWnd.h"
+#include "CatDialog.h"
 #include "muuli_wdr.h"
 #include <wx/settings.h>
 
@@ -31,8 +32,11 @@
 IMPLEMENT_DYNAMIC_CLASS(CTransferWnd,wxPanel)
 
 BEGIN_EVENT_TABLE(CTransferWnd,wxPanel)
-
+	EVT_MULENOTEBOOK_PAGE_CHANGED(ID_CATEGORIES,CTransferWnd::OnSelchangeDltab)
+	EVT_RIGHT_DOWN(CTransferWnd::OnNMRclickDLtab)
+	EVT_SPLITTER_SASH_POS_CHANGED(ID_SPLATTER, CTransferWnd::OnSashPositionChanged)
 END_EVENT_TABLE()
+
   // handled in controls ProcessEvents()
   //  EVT_MENU(MP_SWITCHCTRL,CTransferWnd::SwitchUploadList)
 #include <wx/splitter.h>
@@ -64,8 +68,12 @@ CTransferWnd::CTransferWnd(wxWindow* pParent /*=NULL*/)
   queueSizer->Layout();
   //subC2->Layout();
   queuelistctrl->Show(FALSE);
-
-  windowtransferstate=1;
+  // allow notebook to dispatch right mouse clicks to us
+  CMuleNotebook* nb=(CMuleNotebook*)FindWindowById(ID_CATEGORIES);
+  nb->SetMouseListener(GetEventHandler());
+    
+  windowtransferstate=false;
+  CatMenu=false;
 }
 
 CTransferWnd::~CTransferWnd()
@@ -78,11 +86,26 @@ BEGIN_MESSAGE_MAP(CTransferWnd, CResizableDialog)
 END_MESSAGE_MAP()
 #endif
 
-#if 0
 BOOL CTransferWnd::OnInitDialog(){
+	m_dlTab=(CMuleNotebook*)FindWindowById(ID_CATEGORIES);
+
+	// show & cat-tabs
+	sprintf(theApp.glob_prefs->GetCategory(0)->title, "%s",GetCatTitle(theApp.glob_prefs->GetAllcatType()).GetBuffer());
+
+	sprintf(theApp.glob_prefs->GetCategory(0)->incomingpath,"%s",theApp.glob_prefs->GetIncomingDir());
+	for (int ix=0;ix<theApp.glob_prefs->GetCatCount();ix++) {
+		wxPanel* nullPanel=new wxPanel(m_dlTab);
+		wxString tmpstrstr(theApp.glob_prefs->GetCategory(ix)->title);
+		m_dlTab->AddPage(nullPanel,"-"); // just temporary string. 
+		// for some odd reason, wxwin2.5 and gtk2 will not allow non utf strings for AddPage()
+		// but they will be accepted in SetPageText().. so let's use this as a countermeasure
+		m_dlTab->SetPageText(ix,tmpstrstr);
+	}
+
+#if 0
 	CResizableDialog::OnInitDialog();
 	Localize();
-	windowtransferstate = 1;
+	windowtransferstate = false;
 	uploadlistctrl.Init();
 	downloadlistctrl.Init();
 	queuelistctrl.Init();
@@ -117,10 +140,10 @@ BOOL CTransferWnd::OnInitDialog(){
 	m_iOldToolTipItemDown = -1;
 	m_iOldToolTipItemUp = -1;
 	m_iOldToolTipItemQueue = -1;
-
+#endif
 	return true;
 }
-#endif
+
 
 void CTransferWnd::ShowQueueCount(uint32 number){
 	char buffer[100];
@@ -517,14 +540,14 @@ BOOL CTransferWnd::OnToolTipNotify(UINT id, NMHDR *pNMH, LRESULT *pResult)
 
 void CTransferWnd::SwitchUploadList(wxCommandEvent& evt)
 {
-	if( windowtransferstate == 1){
+	if( windowtransferstate == false){
 #if 0
 		uploadlistctrl.Hide();
 		queuelistctrl.Visable();
 		windowtransferstate = 0;
 		GetDlgItem(IDC_UPLOAD_TEXT)->SetWindowText(GetResString(IDS_ONQUEUE));
 #endif
-		windowtransferstate=0;
+		windowtransferstate=true;
 		// hide the upload list
 		queueSizer->Remove(uploadlistctrl);
 		uploadlistctrl->Show(FALSE);
@@ -540,7 +563,7 @@ void CTransferWnd::SwitchUploadList(wxCommandEvent& evt)
 		windowtransferstate = 1;
 		GetDlgItem(IDC_UPLOAD_TEXT)->SetWindowText(GetResString(IDS_TW_UPLOADS));
 #endif
-		windowtransferstate=1;
+		windowtransferstate=false;
 		// hide the queuelist
 		queueSizer->Remove(queuelistctrl);
 		queuelistctrl->Show(FALSE);
@@ -563,3 +586,263 @@ void CTransferWnd::Localize(){
 	queuelistctrl.Localize();
 #endif
 }
+
+
+void CTransferWnd::OnSelchangeDltab(wxNotebookEvent& evt)
+{
+  downloadlistctrl->ChangeCategory(evt.GetSelection());
+  downloadlistctrl->InitSort();
+}
+
+void CTransferWnd::OnNMRclickDLtab(wxMouseEvent& evt) {
+	CMuleNotebook* nb=(CMuleNotebook*)FindWindowById(ID_CATEGORIES);
+	if(nb->GetSelection()==-1) {
+		return;
+	}
+	
+	// Avoid opening another menu when it's already open
+	if (CatMenu==false) {  
+		
+		CatMenu=true;
+		wxMenu* menu=new wxMenu(GetResString(IDS_CAT));
+
+		if(nb->GetSelection()==0) {
+			wxMenu* m_CatMenu=new wxMenu();
+
+			m_CatMenu->Append(MP_CAT_SET0,GetResString(IDS_ALL) );
+			m_CatMenu->Append(MP_CAT_SET0+1,GetResString(IDS_ALLOTHERS) );
+			m_CatMenu->AppendSeparator();
+			m_CatMenu->Append(MP_CAT_SET0+2,GetResString(IDS_STATUS_NOTCOMPLETED) );
+			m_CatMenu->Append(MP_CAT_SET0+3,GetResString(IDS_DL_TRANSFCOMPL) );
+			m_CatMenu->Append(MP_CAT_SET0+4,GetResString(IDS_WAITING) );
+			m_CatMenu->Append(MP_CAT_SET0+5,GetResString(IDS_DOWNLOADING) );
+			m_CatMenu->Append(MP_CAT_SET0+6,GetResString(IDS_ERRORLIKE) );
+			m_CatMenu->Append(MP_CAT_SET0+7,GetResString(IDS_PAUSED) );
+			m_CatMenu->Append(MP_CAT_SET0+8,GetResString(IDS_STOPPED) );
+			m_CatMenu->AppendSeparator();
+			m_CatMenu->Append(MP_CAT_SET0+9,GetResString(IDS_VIDEO) );
+			m_CatMenu->Append(MP_CAT_SET0+10,GetResString(IDS_AUDIO) );
+			m_CatMenu->Append(MP_CAT_SET0+11,GetResString(IDS_SEARCH_ARC) );
+			m_CatMenu->Append(MP_CAT_SET0+12,GetResString(IDS_SEARCH_CDIMG) );
+			m_CatMenu->Append(MP_CAT_SET0+13,GetResString(IDS_SEARCH_PICS) );
+			m_CatMenu->Append(MP_CAT_SET0+14,GetResString(IDS_TEXT) );
+			//m_CatMenu.CheckMenuItem( MP_CAT_SET0+theApp.glob_prefs->GetAllcatType() ,MF_CHECKED | MF_BYCOMMAND);
+			menu->Append(47321,GetResString(IDS_CHANGECATVIEW),m_CatMenu);
+		}
+
+		menu->Append(MP_CAT_ADD,GetResString(IDS_CAT_ADD));
+		menu->Append(MP_CAT_EDIT,GetResString(IDS_CAT_EDIT));
+		menu->Append(MP_CAT_REMOVE, GetResString(IDS_CAT_REMOVE));
+		menu->AppendSeparator();
+		//menu->Append(472834,GetResString(IDS_PRIORITY),m_PrioMenu);
+
+		menu->Append(MP_CANCEL,GetResString(IDS_MAIN_BTN_CANCEL) );
+		menu->Append(MP_STOP, GetResString(IDS_DL_STOP));
+		menu->Append(MP_PAUSE, GetResString(IDS_DL_PAUSE));
+		menu->Append(MP_RESUME, GetResString(IDS_DL_RESUME));
+		//menu->Append(MP_RESUMENEXT, GetResString(IDS_DL_RESUMENEXT));                                                                                
+		// the point coming from mulenotebook control isn't in screen coordinates
+		// (unlike std mouse event, which always returns screen coordinates)
+		// so we must do the conversion here
+		wxPoint pt=evt.GetPosition();
+		wxPoint newpt=nb->ClientToScreen(pt);
+		newpt=ScreenToClient(newpt);
+		//evt.Skip();
+		PopupMenu(menu,newpt);
+		delete menu;
+
+		CatMenu=false;
+	}
+}
+
+bool CTransferWnd::ProcessEvent(wxEvent& evt)
+{
+	if(evt.GetEventType()!=wxEVT_COMMAND_MENU_SELECTED) {
+		return wxPanel::ProcessEvent(evt);
+	}
+	/*
+	if(evt.GetEventObject()!=this)
+	return wxPanel::ProcessEvent(evt);
+	*/
+	wxCommandEvent& event=(wxCommandEvent&)evt;
+	switch(event.GetId()) {
+		case MP_CAT_SET0: 
+		case MP_CAT_SET0+1: 
+		case MP_CAT_SET0+2: 
+		case MP_CAT_SET0+3: 
+		case MP_CAT_SET0+4: 
+		case MP_CAT_SET0+5: 
+		case MP_CAT_SET0+6: 
+		case MP_CAT_SET0+7:
+		case MP_CAT_SET0+8: 
+		case MP_CAT_SET0+9:
+		case MP_CAT_SET0+10: 
+		case MP_CAT_SET0+11:
+		case MP_CAT_SET0+12: 
+		case MP_CAT_SET0+13: 
+		case MP_CAT_SET0+14: {
+			theApp.glob_prefs->SetAllcatType(event.GetId()-MP_CAT_SET0);
+			sprintf(theApp.glob_prefs->GetCategory(0)->title, "%s", GetCatTitle(theApp.glob_prefs->GetAllcatType()).GetBuffer());
+			CString csName;
+			csName.Format("%s", theApp.glob_prefs->GetCategory(0)->title );
+			EditCatTabLabel(0,csName);
+			downloadlistctrl->ChangeCategory(0);
+			downloadlistctrl->InitSort();
+			break;
+		}
+
+		case MP_CAT_ADD: {
+			int m_nLastCatTT=-1;
+			int newindex=AddCategorie("?",theApp.glob_prefs->GetIncomingDir(),"",false);
+			//m_dlTab.InsertItem(newindex,theApp.glob_prefs->GetCatego
+			//	       ry(newindex)->title);
+			wxPanel* nullPanel=new wxPanel(m_dlTab,-1);
+			m_dlTab->AddPage(nullPanel,theApp.glob_prefs->GetCategory(newindex)->title);
+			CCatDialog dialog(this,newindex);
+			dialog.OnInitDialog();
+			//dialog.DoModal();
+			dialog.ShowModal();
+			#warning TODO: fix this
+			//theApp.emuledlg->searchwnd->UpdateCatTabs();
+			EditCatTabLabel(newindex,theApp.glob_prefs->GetCategory(newindex)->title);
+			theApp.glob_prefs->SaveCats();
+			break;
+		}
+		case MP_CAT_EDIT: {
+			int m_nLastCatTT=-1;
+			CCatDialog dialog(this,m_dlTab->GetSelection());
+			dialog.OnInitDialog();
+			dialog.ShowModal();
+
+			CString csName;
+			csName.Format("%s", theApp.glob_prefs->GetCategory(m_dlTab->GetSelection())->title );
+			EditCatTabLabel(m_dlTab->GetSelection(),csName);
+
+			#warning TODO: fix this
+			//theApp.emuledlg->searchwnd.UpdateCatTabs();
+			theApp.glob_prefs->SaveCats();
+			break;
+		}
+		case MP_CAT_REMOVE: {
+			int m_nLastCatTT=-1;
+			theApp.downloadqueue->ResetCatParts(m_dlTab->GetSelection());
+			theApp.glob_prefs->RemoveCat(m_dlTab->GetSelection());
+			m_dlTab->RemovePage(m_dlTab->GetSelection());
+			m_dlTab->SetSelection(0);
+			downloadlistctrl->ChangeCategory(0);
+			theApp.glob_prefs->SaveCats();
+			if (theApp.glob_prefs->GetCatCount()==1) theApp.glob_prefs->SetAllcatType(0);
+			#warning TODO: fix this
+			//theApp.emuledlg->searchwnd.UpdateCatTabs();
+			break;
+		}
+		case MP_PRIOLOW: {
+			theApp.downloadqueue->SetCatPrio(m_dlTab->GetSelection(),PR_LOW);
+			break;
+		}
+		case MP_PRIONORMAL: {
+			theApp.downloadqueue->SetCatPrio(m_dlTab->GetSelection(),PR_NORMAL);
+			break;
+		}
+		case MP_PRIOHIGH: {
+			theApp.downloadqueue->SetCatPrio(m_dlTab->GetSelection(),PR_HIGH );
+			break;
+		}
+		case MP_PRIOAUTO: {
+			theApp.downloadqueue->SetCatPrio(m_dlTab->GetSelection(),PR_AUTO );
+			break;
+		}
+		case MP_PAUSE: {
+			theApp.downloadqueue->SetCatStatus(m_dlTab->GetSelection(),MP_PAUSE);
+			break;
+		}
+		case MP_STOP : {
+			theApp.downloadqueue->SetCatStatus(m_dlTab->GetSelection(),MP_STOP);
+			break;
+		}
+
+		case MP_CANCEL: 
+			if (wxMessageBox(GetResString(IDS_CATEGORY_DELETE),GetResString(IDS_CONFIRMATION),
+			   wxYES_NO|wxCENTRE|wxICON_EXCLAMATION) == wxYES) {
+				theApp.downloadqueue->SetCatStatus(m_dlTab->GetSelection(),MP_CANCEL);
+			}
+			break;
+		
+		case MP_RESUME: {
+			theApp.downloadqueue->SetCatStatus(m_dlTab->GetSelection(),MP_RESUME);
+			break;
+		}
+		#if 0
+		case MP_RESUMENEXT:
+			theApp.downloadqueue->StartNextFile(m_dlTab->GetSelection());
+			break;
+		#endif
+		case IDC_UPLOAD_ICO: {
+			wxCommandEvent nullEvt;
+			SwitchUploadList(nullEvt);
+			break;
+		}
+		case IDC_QUEUE_REFRESH_BUTTON: {
+			#warning TODO: fix this
+			//OnBnClickedQueueRefreshButton();
+			break;
+		}
+		default: {
+			return wxPanel::ProcessEvent(evt);
+		}
+	}
+	return false;
+}
+
+int CTransferWnd::AddCategorie(CString newtitle,CString newincoming,CString newcomment,bool addTab){
+        Category_Struct* newcat=new Category_Struct;
+
+        sprintf(newcat->title,"%s",newtitle.GetBuffer());
+        newcat->prio=0;
+        sprintf(newcat->incomingpath,"%s",newincoming.GetBuffer());
+        sprintf(newcat->comment,"%s",newcomment.GetBuffer());
+        int index=theApp.glob_prefs->AddCat(newcat);
+        
+        if (addTab) {
+	  //m_dlTab.InsertItem(index,newtitle);
+	  wxPanel* nullPanel=new wxPanel(m_dlTab,-1);
+	  m_dlTab->AddPage(nullPanel,newtitle);
+	}
+        return index;
+}
+
+void CTransferWnd::EditCatTabLabel(int index,CString newlabel) {
+  //TCITEM tabitem;
+  //tabitem.mask = TCIF_PARAM;
+  //m_dlTab.GetItem(index,&tabitem);
+  //tabitem.mask = TCIF_TEXT;
+  
+  if (theApp.glob_prefs->ShowCatTabInfos()) {
+    CPartFile* cur_file;
+    uint16 count,dwl;
+    count=dwl=0;
+    for (int i=0;i<theApp.downloadqueue->GetFileCount();i++) {
+      cur_file=theApp.downloadqueue->GetFileByIndex(i);
+      if (cur_file==0) continue;
+      if (CheckShowItemInGivenCat(cur_file,index)) {
+	count++;
+	if (cur_file->GetTransferingSrcCount()>0) dwl++;
+	//                              speed+=cur_file->GetDatarate()/1024.0f;
+	//                              size+=cur_file->GetFileSize();
+	//                              trsize+=cur_file->GetCompletedSize();
+      }
+    }
+    CString title=newlabel;
+    newlabel.Format("%s (%i/%i)",title.GetData(),dwl,count);
+  }
+  
+  //tabitem.pszText = newlabel.LockBuffer();
+  //m_dlTab.SetItem(index,&tabitem);
+  //newlabel.UnlockBuffer();
+  m_dlTab->SetPageText(index,newlabel);
+}
+
+void CTransferWnd::OnSashPositionChanged()
+{
+	theApp.xmuledlg->split_pos = ((wxSplitterWindow*)FindWindow("splitterWnd"))->GetSashPosition();
+}
