@@ -169,11 +169,12 @@ wxThread::ExitCode AsyncDNS::Entry()
   int errorno=0;
   char dataBuf[512]={0};
 
-#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
-  result = gethostbyname_r(ipName.GetData(),&ret,dataBuf,sizeof(dataBuf),&errorno); 
-#else
+#if defined(__linux__)
   gethostbyname_r(ipName.GetData(),&ret,dataBuf,sizeof(dataBuf),&result,&errorno);
-#endif /* __FreeBSD__ */
+#else
+  result = gethostbyname_r(ipName.GetData(),&ret,dataBuf,sizeof(dataBuf),&errorno); 
+#endif
+
   if(result) {
     unsigned long addr=*(unsigned long*)ret.h_addr;
     struct sockaddr_in* newsi=(struct sockaddr_in*)malloc(sizeof(struct sockaddr_in));//new struct sockaddr_in;
