@@ -122,30 +122,29 @@ uint32 CUpDownClient::GetScore(bool sysvalue, bool isdownloading, bool onlybasev
 	// client finally gets. so it could happen that he is queued first because of a 
 	// high prio file, but then asks for something completely different.
 	int filepriority = 10; // standard
-	if(reqfileid != NULL){ 
-		if(theApp.sharedfiles->GetFileByID(reqfileid) != NULL){ 
-			switch(theApp.sharedfiles->GetFileByID(reqfileid)->GetPriority()){ 
-				case PR_VERYHIGH:
-					if (theApp.sharedfiles->GetFileByID(reqfileid)->IsAutoPrioritized()) {
+	CKnownFile* pFile = theApp.sharedfiles->GetFileByID(GetUploadFileID());
+	if(pFile != NULL){ 
+		switch(pFile->GetUpPriority()){ 
+			case PR_VERYHIGH:
+				if (pFile->IsAutoUpPriority()) {
 					filepriority = 35;
-					} else {
-						filepriority = 50;
-					}
-					break;
-				case PR_HIGH: 
-					filepriority = 20; 
-					break; 
-				case PR_LOW: 
-					filepriority = 5; 
-					break; 
-				case PR_VERYLOW:
-					filepriority = 2;
-					break;
-				case PR_NORMAL: 
-					default: 
-					filepriority = 10; 
+				} else {
+					filepriority = 50;
+				}
+				break;
+			case PR_HIGH: 
+				filepriority = 20; 
 				break; 
-			} 
+			case PR_LOW: 
+				filepriority = 5; 
+				break; 
+			case PR_VERYLOW:
+				filepriority = 2;
+				break;
+			case PR_NORMAL: 
+			default: 
+				filepriority = 10; 
+			break; 
 		} 
 	} 
 	// calculate score, based on waitingtime and other factors
@@ -308,14 +307,14 @@ bool CUpDownClient::CreateNextBlockPackage(){
 				}
 			}
 
-			memcpy(reqfileid,currentblock->FileID,16);
+			SetUploadFileID(currentblock->FileID);
 			if (m_byDataCompVer == 1 && (!strstr(srcfile->GetFileName(),".zip")) && (!strstr(srcfile->GetFileName(),".rar")) && (!strstr(srcfile->GetFileName(),".ace")))
 				CreatePackedPackets(filedata,togo,currentblock);
 			else
 				CreateStandartPackets(filedata,togo,currentblock);
 			
 			// file statistic
-			srcfile->statistic.AddTransferd(togo);
+			srcfile->statistic.AddTransferred(togo);
 
 			m_DoneBlocks_list.AddHead(m_BlockRequests_queue.RemoveHead());
 			delete[] filedata;
@@ -377,6 +376,7 @@ void CUpDownClient::ProcessUpFileStatus(char* packet,uint32 size){
 		}
 
 	}
+	tempreqfile->NewAvailPartsInfo();
 	theApp.xmuledlg->transferwnd->queuelistctrl->RefreshClient(this);
 	delete data;
 }
@@ -393,7 +393,7 @@ void CUpDownClient::CreateStandartPackets(byte* data,uint32 togo, Requested_Bloc
 			nPacketSize = togo;
 		togo -= nPacketSize;
 		Packet* packet = new Packet(OP_SENDINGPART,nPacketSize+24);
-		memcpy(&packet->pBuffer[0],reqfileid,16);
+		memcpy(&packet->pBuffer[0],GetUploadFileID(),16);
 		uint32 statpos = (currentblock->EndOffset - togo) - nPacketSize;
 		memcpy(&packet->pBuffer[16],&statpos,4);
 		uint32 endpos = (currentblock->EndOffset - togo);
@@ -425,7 +425,7 @@ void CUpDownClient::CreatePackedPackets(byte* data,uint32 togo, Requested_Block_
 			nPacketSize = togo;
 		togo -= nPacketSize;
 		Packet* packet = new Packet(OP_COMPRESSEDPART,nPacketSize+24,OP_EMULEPROT);
-		memcpy(&packet->pBuffer[0],reqfileid,16);
+		memcpy(&packet->pBuffer[0],GetUploadFileID(),16);
 		uint32 statpos = currentblock->StartOffset;
 		memcpy(&packet->pBuffer[16],&statpos,4);
 		memcpy(&packet->pBuffer[20],&newsize,4);
@@ -435,6 +435,26 @@ void CUpDownClient::CreatePackedPackets(byte* data,uint32 togo, Requested_Block_
 	delete[] output;
 }
 
+void CUpDownClient::SetUploadFileID(uchar* tempreqfileid){
+	CKnownFile* newreqfile = NULL;
+	if( tempreqfileid )
+		newreqfile = theApp.sharedfiles->GetFileByID(tempreqfileid);
+	CKnownFile* oldreqfile = theApp.sharedfiles->GetFileByID(requpfileid);
+	if(newreqfile == oldreqfile)
+		return;
+	if(newreqfile){
+		newreqfile->AddQueuedCount();
+		newreqfile->AddUploadingClient(this);
+		memcpy(requpfileid,tempreqfileid,16);
+	}
+	else{
+		memset(requpfileid, 0, 16);
+	}
+	if(oldreqfile){
+		oldreqfile->SubQueuedCount();
+		oldreqfile->RemoveUploadingClient(this);
+	}
+}
 
 void CUpDownClient::AddReqBlock(Requested_Block_Struct* reqblock){
 
