@@ -178,7 +178,7 @@ void URLDecode(wxString& result, const char* buff)
 		}
 	}
 	result = buff2;
-	free(buff2);
+	delete[] buff2;
 }
 
 wxString URLEncode(wxString sIn){
