@@ -159,7 +159,7 @@ void Packet::PackPacket(){
 	assert (!m_bSplitted);
 	BYTE* output = new BYTE[size+300];
 	uLongf newsize = size+300;
-	uint16 result = compress2(output,&newsize,(BYTE*)pBuffer,size,9);
+	uint16 result = compress2(output,&newsize,(BYTE*)pBuffer,size,Z_BEST_COMPRESSION);
 	if (result != Z_OK || size <= newsize){
 		delete[] output;
 		return;
@@ -170,11 +170,11 @@ void Packet::PackPacket(){
 	m_bPacked = true;
 }
 
-bool Packet::UnPackPacket(){
+bool Packet::UnPackPacket(UINT uMaxDecompressedSize){
 	assert ( prot == OP_PACKEDPROT); 
 	uint32 nNewSize = size*10+300;
-	if (nNewSize > 50000)
-		nNewSize = 50000;
+	if (nNewSize > uMaxDecompressedSize)
+		nNewSize = uMaxDecompressedSize;
 	BYTE* unpack = new BYTE[nNewSize];
 	uLongf unpackedsize = nNewSize;
 	uint16 result = uncompress(unpack,&unpackedsize,(BYTE*)pBuffer,size);
