@@ -22,9 +22,10 @@
 #include "types.h"
 #include "opcodes.h"
 #include "otherstructs.h"
-//#include "zlib/zlib.h"
 #include "CFile.h"
 #include <exception>
+#include <zlib.h>
+
 //			CLIENT TO SERVER
 
 
@@ -47,7 +48,7 @@ public:
 	bool	IsSplitted()			{return m_bSplitted;}
 	bool	IsLastSplitted()		{return m_bLastSplitted;}
 	void	PackPacket();
-	bool	UnPackPacket();
+	bool	UnPackPacket(UINT uMaxDecompressedSize = 50000);
 	char*	pBuffer;
 	uint32	size;
 	uint8	opcode;
