@@ -19,13 +19,11 @@
 //#include "stdafx.h"
 #include "server.h"
 #include "opcodes.h"
+#include "otherfunctions.h"
 #include "xmule.h"
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-//#define nstrdup strdup
-extern char* nstrdup(char*);
-
 #include <wx/listimpl.cpp>
 WX_DEFINE_LIST(TagList);
 
