@@ -4,7 +4,7 @@
 // Author:      Robert Roebling
 // Created:     01/02/97
 // Modified:    22/10/98 - almost total rewrite, simpler interface (VZ)
-// Id:          $Id: treectlc.cpp,v 1.7 2003/03/28 15:22:08 un-thesis Exp $
+// Id:          $Id: treectlc.cpp,v 1.8 2003/09/08 01:04:18 malware Exp $
 // Copyright:   (c) 1998 Robert Roebling, Julian Smart and Markus Holzem
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -785,6 +785,8 @@ void wxGenericCTreeCtrl::Init()
     m_current = m_key_current = m_anchor = (wxGenericCTreeItem *) NULL;
     m_hasFocus = FALSE;
     m_dirty = FALSE;
+    m_check1 = NULL;
+    m_check2 = NULL;
 
     m_lineHeight = 10;
     m_indent = 15;
@@ -924,6 +926,9 @@ wxGenericCTreeCtrl::~wxGenericCTreeCtrl()
         delete m_imageListState;
     if (m_ownsImageListButtons)
         delete m_imageListButtons;
+
+    delete m_check1;
+    delete m_check2;
 }
 
 // -----------------------------------------------------------------------------
