@@ -3,7 +3,7 @@
 // Purpose:     includes all xh_*.h files
 // Author:      Vaclav Slavik
 // Created:     2000/03/05
-// RCS-ID:      $Id: xh_all.h,v 1.1 2003/03/01 23:12:38 tiku Exp $
+// RCS-ID:      $Id: xh_all.h,v 1.2 2003/08/02 04:29:30 Un-Thesis Exp $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -47,5 +47,7 @@
 #include "wx/xrc/xh_gdctl.h"
 #include "wx/xrc/xh_frame.h"
 #include "wx/xrc/xh_scwin.h"
+#include "wx/xrc/xh_split.h"
+#include "wx/xrc/xh_wizrd.h"
 
 #endif // _WX_XMLRES_H_
