@@ -658,17 +658,22 @@ CxmuleDlg::~CxmuleDlg()
 
 	theApp.OnlineSig(true);
 
-	delete theApp.sharedfiles;
-	delete theApp.serverconnect;
-	delete theApp.serverlist;
-	delete theApp.knownfiles;
-	delete theApp.searchlist;
-	delete theApp.clientcredits;
-	delete theApp.downloadqueue;
-	delete theApp.uploadqueue;
-	delete theApp.clientlist;
-	delete theApp.friendlist;
-	delete theApp.glob_prefs;
+	// TODO: We want to free the memory used by the webserver
+	//       but currently it does wait in accept().
+	// delete theApp.webserver;
+	delete theApp.serverlist; theApp.serverlist = NULL;
+	delete theApp.searchlist; theApp.searchlist = NULL;
+	delete theApp.clientcredits; theApp.clientcredits = NULL;
+	// Destroying CDownloadQueue calls destructor for CPartFile
+	// calling CSharedFileList::SafeAddKFile occasally.
+	delete theApp.downloadqueue; theApp.downloadqueue = NULL;
+	delete theApp.sharedfiles; theApp.sharedfiles = NULL;
+	delete theApp.knownfiles; theApp.knownfiles = NULL;
+	delete theApp.uploadqueue; theApp.uploadqueue = NULL;
+	delete theApp.clientlist; theApp.clientlist = NULL;
+	delete theApp.friendlist; theApp.friendlist = NULL;
+	delete theApp.glob_prefs; theApp.glob_prefs = NULL;
+	delete theApp.serverconnect; theApp.serverconnect = NULL;
 }
 #if 0
 void CxmuleDlg::DoDataExchange(CDataExchange* pDX){
@@ -1333,8 +1338,9 @@ void CxmuleDlg::OnClose(wxCloseEvent& evt)
   theApp.OnlineSig(); // Added By Bouc7 
 
   // Close sockets to avoid new clients coming in
-  theApp.listensocket->Destroy();
+  theApp.listensocket->StopListening();
   theApp.clientudp->Destroy();
+  theApp.serverconnect->Disconnect();
 
   // Signal the hashing thread to terminate
   CAddFileThread::Shutdown();
